(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    596850,      12103]
NotebookOptionsPosition[    586048,      11861]
NotebookOutlinePosition[    586403,      11877]
CellTagsIndexPosition[    586360,      11874]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
(* ALL of the code in this notebook was written by me, Catherine Osborn. I \
will denote passages of code over which I collaborated with my partners about \
the logic *)\
\>", "Text",
 CellChangeTimes->{{3.544801958080814*^9, 3.5448020563787622`*^9}},
 FontSize->16],

Cell[CellGroupData[{

Cell["\<\
(* Model using given parameters and initial conditions for Simplified AP*)\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5437061157847958`*^9, 3.543706118537395*^9}, {
   3.543706158319888*^9, 3.543706201079421*^9}, {3.543706258486834*^9, 
   3.54370628947254*^9}, 3.543707065376738*^9},
 FontSize->16,
 Background->RGBColor[1, 0.9, 0.8]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Collaborated", " ", "with", " ", "Elena", " ", "and", " ", "Julia", " ", 
   "on", " ", "the", " ", "Simplified", " ", "Action", " ", "Potential", " ", 
   "solved", " ", "using", " ", "NDSolve"}], " ", "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.544802062709573*^9, 3.5448020914517307`*^9}, {
  3.54480213542591*^9, 3.544802152667059*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"parameters", " ", "for", " ", "currents", " ", "Ileak"}], ",", 
    " ", "INa", ",", " ", "INaP", ",", " ", 
    RowBox[{"and", " ", "Ik"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"parametersNaNaPKleak", "=", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"gleak", "\[Rule]", " ", "0.005"}], " ", 
      RowBox[{"(*", "uS", "*)"}], ",", " ", "\[IndentingNewLine]", 
      RowBox[{"gNa", "\[Rule]", " ", "0.7"}], " ", 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gNaP", "\[Rule]", " ", "0.05"}], " ", 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gK", "\[Rule]", "1.3"}], " ", 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"eleak", "\[Rule]", " ", 
       RowBox[{"-", "50"}]}], " ", 
      RowBox[{"(*", "mV", "*)"}], ",", " ", "\[IndentingNewLine]", 
      RowBox[{"eNa", "\[Rule]", " ", "60"}], 
      RowBox[{"(*", "mV", "*)"}], ",", " ", "\[IndentingNewLine]", 
      RowBox[{"eK", "\[Rule]", " ", 
       RowBox[{"-", "80"}]}], 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"cm", "\[Rule]", " ", "0.040"}], 
      RowBox[{"(*", "nF", "*)"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Initial", " ", "conditions", " ", "for", " ", "steady"}], 
        "-", 
        RowBox[{"state", " ", "and", " ", "time", " ", "constants"}]}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"mNaP0", "\[Rule]", "0.002"}], ",", "\[IndentingNewLine]", 
      RowBox[{"hNaP0", "\[Rule]", "0.797"}], ",", "\[IndentingNewLine]", 
      RowBox[{"n0", "\[Rule]", "0.158"}], ",", "\[IndentingNewLine]", 
      RowBox[{"mNa0", "\[Rule]", "0.015"}], ",", "\[IndentingNewLine]", 
      RowBox[{"hNa0", "\[Rule]", "0.981"}], ",", "\[IndentingNewLine]", 
      RowBox[{"v0", "\[Rule]", 
       RowBox[{"-", "71.847"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"taumNaP", "\[Rule]", "0.1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"tauhNaP", "\[Rule]", "150"}], ",", "\[IndentingNewLine]", 
      RowBox[{"tauM", "\[Rule]", "0.1"}]}], "}"}]}], ";"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.543706309910058*^9, 3.5437064470428143`*^9}, 
   3.543706491864929*^9, {3.5437069332683277`*^9, 3.543706986850026*^9}, 
   3.543707065376924*^9, {3.5448021071936493`*^9, 3.544802120640822*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "functions", " ", "for", " ", "simplified", " ", "action", " ", 
    "potential"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"pulse", "[", 
      RowBox[{"t_", ",", "t0_", ",", "w_", ",", "p_", ",", "D_", ",", "A_"}], 
      "]"}], ":=", 
     RowBox[{"A", 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"UnitStep", "[", 
           RowBox[{"t", "-", "i"}], "]"}], " ", "-", " ", 
          RowBox[{"UnitStep", "[", 
           RowBox[{"t", "-", 
            RowBox[{"(", 
             RowBox[{"i", "+", "w"}], ")"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "t0", ",", 
           RowBox[{"t0", "+", "D"}], ",", "p"}], "}"}]}], "]"}], ")"}]}]}], 
    ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"pulse", " ", "function", " ", "for", " ", "injection"}], " ", 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Inj", "[", "t_", "]"}], ":=", " ", 
     RowBox[{"pulse", "[", 
      RowBox[{"t", ",", "0", ",", "1", ",", "2", ",", "1", ",", "1"}], 
      "]"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"Injection", " ", "function"}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ileak", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"gleak", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eleak"}], ")"}]}], "/.", 
      "parametersNaNaPKleak"}]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"function", " ", "for", " ", "iLeak", " ", "current"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iNaP", "[", 
      RowBox[{"v_", ",", "mNaP_", ",", "hNaP_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gNaP", "*", "mNaP", "*", "hNaP", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eNa"}], ")"}]}], "/.", "parametersNaNaPKleak"}]}], 
    ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "INaP"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iNa", "[", 
      RowBox[{"v_", ",", "mNa_", ",", "hNa_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gNa", "*", 
       RowBox[{"mNa", "^", "3"}], "*", "hNa", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eNa"}], ")"}]}], "/.", "parametersNaNaPKleak"}]}], 
    ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "INa"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iK", "[", 
      RowBox[{"v_", ",", "n_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gK", "*", 
       RowBox[{"n", "^", "4"}], "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eK"}], ")"}]}], "/.", "parametersNaNaPKleak"}]}], 
    ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "Ik"}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"minfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "36"}], ")"}], "/", "8.5"}], ")"}]}]}]}], 
       ")"}]}]}], ";"}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
     RowBox[{"dependent", " ", "activation", " ", "of", " ", "INa"}]}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"hinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "44.1"}], ")"}], "/", "7"}], ")"}]}]}], 
       ")"}]}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
     RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "INA"}]}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"tauH", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"3.5", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "35"}], ")"}], "/", "4"}], ")"}]}], "+", 
         RowBox[{"E", "^", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"v", "+", "35"}], ")"}], "/", "25"}], ")"}]}]}]}], 
        ")"}]}], "+", "1"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "time"}], "-", 
     RowBox[{"constant", " ", "of", " ", "INa"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"mNaPinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"v", "+", "47.1"}], ")"}]}], "/", "4.1"}], ")"}]}]}], 
       ")"}]}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
     RowBox[{"dependent", " ", "activation", " ", "of", " ", "INaP"}]}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"hNaPinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "65"}], ")"}], "/", "5"}], ")"}]}]}], ")"}]}]}],
     ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
     RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "INaP"}]}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ninfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "30"}], ")"}], "/", "25"}], ")"}]}]}]}], 
       ")"}]}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
     RowBox[{"dependent", " ", 
      RowBox[{"(", "in", ")"}], "activation", " ", "of", " ", "IK"}]}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"tauN", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"2.5", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "30"}], ")"}], "/", "40"}], ")"}]}], "+", 
         RowBox[{"E", "^", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"v", "+", "30"}], ")"}], "/", "50"}], ")"}]}]}]}], 
        ")"}]}], "+", "0.01"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "function", " ", "for", " ", "time", " ", "constant", " ", "of", " ", 
     "Ik"}], " ", "*)"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.543706531482589*^9, 3.5437065784297047`*^9}, {
   3.543706626764045*^9, 3.543706640273437*^9}, 3.543707065377075*^9}],

Cell[BoxData[
 RowBox[{"solutionVoltageNaNaPKleak", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"mNaP", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mNaPinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mNaP", "[", "t", "]"}]}], ")"}], "/", "taumNaP"}]}], ",", 
       
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "INaP"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mNaP", "[", "0", "]"}], "\[Equal]", "mNaP0"}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hNaP", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hNaPinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hNaP", "[", "t", "]"}]}], ")"}], "/", "tauhNaP"}]}], ",", 
       " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "INaP"}]}],
         " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hNaP", "[", "0", "]"}], "\[Equal]", "hNaP0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mNa", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"minfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mNa", "[", "t", "]"}]}], ")"}], "/", "tauM"}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "INa"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mNa", "[", "0", "]"}], "\[Equal]", "mNa0"}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hNa", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hNa", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"tauH", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inaction", " ", "of", " ", "INa"}]}], " ",
         "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hNa", "[", "0", "]"}], "\[Equal]", "hNa0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"n", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ninfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"n", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"tauN", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", 
          RowBox[{"(", "in", ")"}], "activation", " ", "of", " ", "Ik"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"n", "[", "0", "]"}], "\[Equal]", "n0"}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", "cm"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"ileak", "[", 
                RowBox[{"v", "[", "t", "]"}], "]"}], "+", 
               RowBox[{"iNaP", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"mNaP", "[", "t", "]"}], ",", 
                 RowBox[{"hNaP", "[", "t", "]"}]}], "]"}], "+", 
               RowBox[{"iNa", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"mNa", "[", "t", "]"}], ",", 
                 RowBox[{"hNa", "[", "t", "]"}]}], "]"}], "+", 
               RowBox[{"iK", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"n", "[", "t", "]"}]}], "]"}]}], ")"}]}], ")"}], "+", 
           RowBox[{"Inj", "[", "t", "]"}]}], ")"}]}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "solving", " ", "for", " ", "voltage", " ", "when", " ", "Iionic"}], 
         " ", "=", " ", 
         RowBox[{"(", 
          RowBox[{"Ileak", "+", "INa", "+", "INaP", "+", "Ik"}], ")"}]}], " ",
         "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"v", "[", "0", "]"}], "\[Equal]", "v0"}]}], "}"}], "/.", 
     "parametersNaNaPKleak"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mNaP", "[", "t", "]"}], ",", 
      RowBox[{"hNaP", "[", "t", "]"}], ",", 
      RowBox[{"mNa", "[", "t", "]"}], ",", 
      RowBox[{"hNa", "[", "t", "]"}], ",", 
      RowBox[{"n", "[", "t", "]"}], ",", 
      RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.543706670579089*^9, 3.5437066954157877`*^9}, 
   3.543707065377235*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"mNaP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hNaP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mNa", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hNa", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.5437067080987463`*^9, 3.5437070653774014`*^9, 
  3.5437078017367153`*^9, 3.543784211774798*^9, 3.543786223758852*^9, 
  3.543787325472645*^9, 3.543787409004044*^9, 3.54378757227698*^9, 
  3.543787732171975*^9, 3.543787770558906*^9, 3.5437905783689404`*^9, 
  3.543790609371956*^9, 3.543831300104973*^9, 3.5438381493344593`*^9, 
  3.543838347789953*^9, 3.543838824708281*^9, 3.543838902009247*^9, 
  3.5438433483185587`*^9, 3.5438514094161463`*^9, 3.5439186924939337`*^9, 
  3.543944031161433*^9, 3.543960690565351*^9, 3.544014794030527*^9, 
  3.544364784959984*^9, 3.544710282339319*^9, 3.544713486704905*^9, 
  3.544727685815292*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Plot", " ", "of", " ", "Simplified", " ", "Action", " ", 
   RowBox[{"Potential", ".", " ", "1"}], " ", "nA", " ", "of", " ", "stim", 
   " ", "for", " ", "1", " ", 
   RowBox[{"ms", "."}]}], " ", "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.543706780452361*^9, 3.543706822561742*^9}, 
   3.543707065377544*^9}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
     "solutionVoltageNaNaPKleak"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"\"\<Time (ms)\>\"", ",", " ", "\"\<Voltage (mV)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.543706729783877*^9, 3.543706751477409*^9}, 
   3.543707065377673*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmHc81f8Xx2WljJAKSVb23vuee917ufvelGipzFRGyUjDqoQGCWWkolSS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Voltage (mV)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 100}, {-71.84694319168652, 42.85578212448909}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.5437067539024677`*^9, 3.543707065377816*^9, 
  3.543707801999399*^9, 3.543784212153247*^9, 3.5437862241724243`*^9, 
  3.543787325947752*^9, 3.54378740926198*^9, 3.543787572436533*^9, 
  3.54378773242883*^9, 3.543787770788622*^9, 3.543790578448556*^9, 
  3.543790609622663*^9, 3.543831300196456*^9, 3.543838149412456*^9, 
  3.543838347873867*^9, 3.5438388252646093`*^9, 3.54383890209442*^9, 
  3.543843348475026*^9, 3.5438514100285873`*^9, 3.543918693250251*^9, 
  3.5439440316643*^9, 3.543960691150341*^9, 3.544014794712599*^9, 
  3.544364785114541*^9, 3.544710282928198*^9, 3.5447134878222637`*^9, 
  3.544727686318162*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(* Whole model action potential. Using given initial conditions. 1 nA for 1 \
ms *)\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{
  3.543706575280715*^9, {3.543706797297977*^9, 3.543706868213551*^9}, 
   3.543707124409595*^9},
 FontSize->16,
 Background->RGBColor[1, 0.9, 0.8]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Parameters", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"parametersAll", "=", "\[IndentingNewLine]", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"v0", "\[Rule]", 
       RowBox[{"-", "71.847"}]}], " ", 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"mNa0", "\[Rule]", "0.015"}], ",", "\[IndentingNewLine]", 
      RowBox[{"hNa0", "\[Rule]", "0.981"}], ",", "\[IndentingNewLine]", 
      RowBox[{"mNaP0", "\[Rule]", "0.002"}], ",", "\[IndentingNewLine]", 
      RowBox[{"hNaP0", "\[Rule]", "0.797"}], ",", "\[IndentingNewLine]", 
      RowBox[{"n0", "\[Rule]", "0.158"}], ",", "\[IndentingNewLine]", 
      RowBox[{"mT0", "\[Rule]", "0.001"}], ",", "\[IndentingNewLine]", 
      RowBox[{"hT0", "\[Rule]", "0.562"}], ",", "\[IndentingNewLine]", 
      RowBox[{"mP0", "\[Rule]", "0"}], ",", "\[IndentingNewLine]", 
      RowBox[{"mN0", "\[Rule]", "0.001"}], ",", "\[IndentingNewLine]", 
      RowBox[{"hN0", "\[Rule]", "0.649"}], ",", "\[IndentingNewLine]", 
      RowBox[{"zSK0", "\[Rule]", "0"}], ",", "\[IndentingNewLine]", 
      RowBox[{"mA0", "\[Rule]", "0.057"}], ",", "\[IndentingNewLine]", 
      RowBox[{"hA0", "\[Rule]", "0.287"}], ",", "\[IndentingNewLine]", 
      RowBox[{"mH0", "\[Rule]", "0.182"}], ",", "\[IndentingNewLine]", 
      RowBox[{"ca20", "\[Rule]", "0.0604"}], " ", 
      RowBox[{"(*", " ", "uM", " ", "*)"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"gNa", "\[Rule]", "0.7"}], 
      RowBox[{"(*", " ", "uS", " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gNaP", "\[Rule]", "0.05"}], 
      RowBox[{"(*", " ", "uS", " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gK", "\[Rule]", "1.3"}], 
      RowBox[{"(*", " ", "uS", " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gleak", "\[Rule]", "0.005"}], 
      RowBox[{"(*", " ", "uS", " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gT", "\[Rule]", "0.1"}], 
      RowBox[{"(*", " ", "uS", " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gP", "\[Rule]", "0.05"}], 
      RowBox[{"(*", " ", "uS", " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gN", "\[Rule]", "0.05"}], 
      RowBox[{"(*", " ", "uS", " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gSK", "\[Rule]", "0.3"}], 
      RowBox[{"(*", " ", "uS", " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gA", "\[Rule]", "1.0"}], 
      RowBox[{"(*", " ", "uS", " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gH", "\[Rule]", "0.005"}], 
      RowBox[{"(*", " ", "uS", " ", "*)"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"eNa", "\[Rule]", "60"}], " ", 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"eK", "\[Rule]", 
       RowBox[{"-", "80"}]}], 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"eleak", "\[Rule]", 
       RowBox[{"-", "50"}]}], 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"eCa", "\[Rule]", "40"}], 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"eH", "\[Rule]", 
       RowBox[{"-", "38.8"}]}], 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"k1", "\[Rule]", 
       RowBox[{"-", "0.0005"}]}], " ", 
      RowBox[{"(*", " ", 
       RowBox[{"M", "/", "nC"}], " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"k2", "\[Rule]", "0.04"}], " ", 
      RowBox[{"(*", " ", 
       RowBox[{"0.04", " ", 
        RowBox[{"ms", "^", 
         RowBox[{"-", "1"}]}]}], " ", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"cm", "\[Rule]", "0.040"}], 
      RowBox[{"(*", "nF", "*)"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"tauM", "\[Rule]", "0.1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"taumNaP", "\[Rule]", "0.1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"tauhNaP", "\[Rule]", "150"}], ",", "\[IndentingNewLine]", 
      RowBox[{"tauhN", "\[Rule]", "25"}], ",", "\[IndentingNewLine]", 
      RowBox[{"taumN", "\[Rule]", "5"}], ",", "\[IndentingNewLine]", 
      RowBox[{"taumP", "\[Rule]", "10"}], ",", "\[IndentingNewLine]", 
      RowBox[{"tauzSK", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"tauhA", "\[Rule]", "20"}]}], "\[IndentingNewLine]", "}"}]}], 
   ";"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{
  3.543706901642074*^9, 3.5437071244097767`*^9, {3.5437076806665916`*^9, 
   3.54370768218541*^9}, {3.543708076681992*^9, 3.543708080234026*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "functions", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"pulse", "[", 
      RowBox[{"t_", ",", "t0_", ",", "w_", ",", "p_", ",", "D_", ",", "A_"}], 
      "]"}], ":=", " ", 
     RowBox[{"A", 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"UnitStep", "[", 
           RowBox[{"t", "-", "i"}], "]"}], " ", "-", " ", 
          RowBox[{"UnitStep", "[", 
           RowBox[{"t", "-", 
            RowBox[{"(", 
             RowBox[{"i", "+", "w"}], ")"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "t0", ",", 
           RowBox[{"t0", "+", "D"}], ",", "p"}], "}"}]}], "]"}], ")"}]}]}], 
    ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"pulse", " ", "function", " ", "for", " ", "injection"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Inj", "[", "t_", "]"}], ":=", " ", 
     RowBox[{"pulse", "[", 
      RowBox[{"t", ",", "0", ",", "1", ",", "2", ",", "1", ",", "1"}], 
      "]"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"Injection", " ", "function"}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"steady", "-", 
     RowBox[{
     "state", " ", "voltage", " ", "dependent", " ", "activation", " ", "and",
       " ", "inactivation", " ", "functions", " ", "with", " ", "time", " ", 
      "constants"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"minfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "36"}], ")"}], "/", "8.5"}], ")"}]}]}]}], 
       ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"hinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "44.1"}], ")"}], "/", "7"}], ")"}]}]}], 
       ")"}]}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
     RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iNa"}]}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"tauH", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"3.5", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "35"}], ")"}], "/", "4"}], ")"}]}], "+", 
         RowBox[{"E", "^", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"v", "+", "35"}], ")"}], "/", "25"}], ")"}]}]}]}], 
        ")"}]}], "+", "1"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "time"}], "-", 
     RowBox[{"constant", " ", "of", " ", "iNa"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"mNaPinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"v", "+", "47.1"}], ")"}]}], "/", "4.1"}], ")"}]}]}], 
       ")"}]}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
     RowBox[{"dependent", " ", "activation", " ", "of", " ", "iNaP"}]}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"hNaPinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "65"}], ")"}], "/", "5"}], ")"}]}]}], ")"}]}]}],
     ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
     RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iNaP"}]}], 
    " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ninfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "30"}], ")"}], "/", "25"}], ")"}]}]}]}], 
       ")"}]}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
     RowBox[{"dependent", " ", 
      RowBox[{"(", "in", ")"}], "activation", " ", "of", " ", "iK"}]}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"tauN", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"2.5", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "30"}], ")"}], "/", "40"}], ")"}]}], "+", 
         RowBox[{"E", "^", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"v", "+", "30"}], ")"}], "/", "50"}], ")"}]}]}]}], 
        ")"}]}], "+", "0.01"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{
    "function", " ", "for", " ", "time", " ", "constant", " ", "of", " ", 
     "ik"}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"mTinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "38"}], ")"}], "/", "5"}], ")"}]}]}]}], 
       ")"}]}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"activation", " ", "function", " ", "iT"}], " ", "*)"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"taumt", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"5", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "28"}], ")"}], "/", "25"}], ")"}]}], "+", 
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"v", "+", "28"}], ")"}]}], "/", "70"}], ")"}]}]}], 
        ")"}]}], "+", "2"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"activation", " ", "time", " ", "constant", " ", "iT"}], "*)"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"hTinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "70.1"}], ")"}], "/", "7"}], ")"}]}]}], 
       ")"}]}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"inactivation", " ", "function", " ", "iT"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"tauht", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"20", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "70"}], ")"}], "/", "65"}], ")"}]}], "+", 
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"v", "+", "70"}], ")"}]}], "/", "65"}], ")"}]}]}], 
        ")"}]}], "+", "1"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"inactivation", " ", "time", " ", "constant", " ", "iT"}], " ", 
    "*)"}], " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"mNinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "30"}], ")"}], "/", "6"}], ")"}]}]}]}], 
       ")"}]}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"activation", " ", "function", " ", "iN"}], " ", "*)"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"hNinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "70"}], ")"}], "/", "3"}], ")"}]}]}], ")"}]}]}],
     ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"inactivation", " ", "function", " ", "iN"}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"mPinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "17"}], ")"}], "/", "3"}], ")"}]}]}]}], 
       ")"}]}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"inactivation", " ", "function", " ", "iP"}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"zSKinfin", "[", "ca2_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0.003", "/", "ca2"}], ")"}], "^", "2"}]}], ")"}]}]}], 
    ";"}], " ", 
   RowBox[{"(*", " ", "iSK", " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"mAinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "27"}], ")"}], "/", "16"}], ")"}]}]}]}], 
       ")"}]}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"activation", " ", "function", " ", "Ia"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"taumA", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "40"}], ")"}], "/", "5"}], ")"}]}], "+", 
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"v", "+", "74"}], ")"}]}], "/", "7.5"}], ")"}]}]}], 
        ")"}]}], "+", "0.37"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"activation", " ", "time", " ", "constant", " ", "Ia"}], " ", 
    "*)"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"hAinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "80"}], ")"}], "/", "11"}], ")"}]}]}], 
       ")"}]}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"inactivation", " ", "function", " ", "constant", " ", "Ia"}], 
    " ", "*)"}], " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"taumH", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"475", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "70"}], ")"}], "/", "11"}], ")"}]}], "+", 
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"v", "+", "70"}], ")"}]}], "/", "11"}], ")"}]}]}], 
        ")"}]}], "+", "50"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{
    "function", " ", "for", " ", "time", " ", "constant", " ", "of", " ", 
     "iH"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"mHinfin", "[", "v_", "]"}], ":=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "79.8"}], ")"}], "/", "5.3"}], ")"}]}]}], 
       ")"}]}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"activation", " ", "function", " ", "iH"}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"I", " ", "ionic", " ", "functions"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ileak", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"gleak", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eleak"}], ")"}]}], "/.", "parametersAll"}]}], 
    ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"function", " ", "for", " ", "iLeak", " ", "current"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iNaP", "[", 
      RowBox[{"v_", ",", "mNaP_", ",", "hNaP_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gNaP", "*", "mNaP", "*", "hNaP", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eNa"}], ")"}]}], "/.", "parametersAll"}]}], ";"}], 
   " ", 
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "INaP"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iNa", "[", 
      RowBox[{"v_", ",", "mNa_", ",", "hNa_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gNa", "*", 
       RowBox[{"(", 
        RowBox[{"mNa", "^", "3"}], ")"}], "*", "hNa", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eNa"}], ")"}]}], "/.", "parametersAll"}]}], ";"}], 
   " ", 
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "INa"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iK", "[", 
      RowBox[{"v_", ",", "n_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gK", "*", 
       RowBox[{"(", 
        RowBox[{"n", "^", "4"}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eK"}], ")"}]}], "/.", "parametersAll"}]}], ";"}], 
   " ", 
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "iK"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iT", "[", 
      RowBox[{"v_", ",", "mT_", ",", "hT_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gT", "*", "mT", "*", "hT", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eCa"}], ")"}]}], "/.", "parametersAll"}]}], ";"}], 
   " ", 
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "iT"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iN", "[", 
      RowBox[{"v_", ",", "mN_", ",", "hN_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gN", "*", "mN", "*", "hN", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eCa"}], ")"}]}], "/.", "parametersAll"}]}], ";"}], 
   
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "iN"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iP", "[", 
      RowBox[{"v_", ",", "mP_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gP", "*", "mP", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eCa"}], ")"}]}], "/.", "parametersAll"}]}], ";"}], 
   
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "iP"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iSK", "[", 
      RowBox[{"v_", ",", "zSK_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gSK", "*", 
       RowBox[{"(", 
        RowBox[{"zSK", "^", "2"}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eK"}], ")"}]}], "/.", "parametersAll"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "iSK"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iA", "[", 
      RowBox[{"v_", ",", "mA_", ",", "hA_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gA", "*", "mA", "*", "hA", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eK"}], ")"}]}], "/.", "parametersAll"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "iA"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"iH", "[", 
      RowBox[{"v_", ",", "mH_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"gH", "*", "mH", "*", 
       RowBox[{"(", 
        RowBox[{"v", "-", "eH"}], ")"}]}], "/.", "parametersAll"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"function", " ", "for", " ", "iH"}], " ", "*)"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{
  3.543706921645649*^9, 3.543707124409917*^9, {3.544802194840732*^9, 
   3.544802256136273*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"solutionVoltageAll", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"mNa", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"minfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"mNa", "[", "t", "]"}]}], ")"}], "/", "tauM"}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "activation", " ", "of", " ", "INa"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"mNa", "[", "0", "]"}], "\[Equal]", "mNa0"}], ",", " ", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"hNa", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"hinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"hNa", "[", "t", "]"}]}], ")"}], "/", 
          RowBox[{"tauH", "[", 
           RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", " ", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "inaction", " ", "of", " ", "INa"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"hNa", "[", "0", "]"}], "\[Equal]", "hNa0"}], ",", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"mNaP", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mNaPinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"mNaP", "[", "t", "]"}]}], ")"}], "/", "taumNaP"}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "activation", " ", "of", " ", "INaP"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"mNaP", "[", "0", "]"}], "\[Equal]", "mNaP0"}], ",", " ", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"hNaP", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"hNaPinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"hNaP", "[", "t", "]"}]}], ")"}], "/", "tauhNaP"}]}], ",",
         " ", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{
          "dependent", " ", "inactivation", " ", "of", " ", "INaP"}]}], " ", 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"hNaP", "[", "0", "]"}], "\[Equal]", "hNaP0"}], ",", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"n", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ninfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"n", "[", "t", "]"}]}], ")"}], "/", 
          RowBox[{"tauN", "[", 
           RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", 
           RowBox[{"(", "in", ")"}], "activation", " ", "of", " ", "Ik"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"n", "[", "0", "]"}], "\[Equal]", "n0"}], ",", " ", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"mT", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mTinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"mT", "[", "t", "]"}]}], ")"}], "/", 
          RowBox[{"taumt", "[", 
           RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "activation", " ", "of", " ", "iT"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"mT", "[", "0", "]"}], "\[Equal]", "mT0"}], ",", " ", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"hT", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"hTinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"hT", "[", "t", "]"}]}], ")"}], "/", 
          RowBox[{"tauht", "[", 
           RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", " ", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iT"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"hT", "[", "0", "]"}], "\[Equal]", "hT0"}], ",", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"mN", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mNinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"mN", "[", "t", "]"}]}], ")"}], "/", "taumN"}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "activation", " ", "of", " ", "iN"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"mN", "[", "0", "]"}], "\[Equal]", "mN0"}], ",", " ", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"hN", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"hNinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"hN", "[", "t", "]"}]}], ")"}], "/", "tauhN"}]}], ",", 
        " ", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iN"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"hN", "[", "0", "]"}], "\[Equal]", "hN0"}], ",", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"mP", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mPinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"mP", "[", "t", "]"}]}], ")"}], "/", "taumP"}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "activation", " ", "of", " ", "iP"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"mP", "[", "0", "]"}], "\[Equal]", "mP0"}], ",", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"zSK", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"zSKinfin", "[", 
             RowBox[{"ca2", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"zSK", "[", "t", "]"}]}], ")"}], "/", "tauzSK"}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "calcium"}], "-", 
          RowBox[{"dependent", " ", "activation", " ", "of", " ", "iSK"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"zSK", "[", "0", "]"}], "\[Equal]", "zSK0"}], ",", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"ca2", "'"}], "[", "t", "]"}], "\[Equal]", " ", 
         RowBox[{
          RowBox[{"k1", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"gT", "*", 
               RowBox[{"mT", "[", "t", "]"}], "*", 
               RowBox[{"hT", "[", "t", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], "-", "eCa"}], ")"}]}], ")"}], 
             "+", 
             RowBox[{"(", 
              RowBox[{"gN", "*", 
               RowBox[{"mN", "[", "t", "]"}], "*", 
               RowBox[{"hN", "[", "t", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], "-", "eCa"}], ")"}]}], ")"}], 
             "+", 
             RowBox[{"(", 
              RowBox[{"gP", "*", 
               RowBox[{"mP", "[", "t", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], "-", "eCa"}], ")"}]}], ")"}]}],
             ")"}]}], "-", 
          RowBox[{"k2", "*", 
           RowBox[{"ca2", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ca2", "[", "0", "]"}], "\[Equal]", "ca20"}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
         "solving", " ", "for", " ", "calcium", " ", "concentration", " ", 
          "within", " ", "the", " ", 
          RowBox[{"cell", ".", " ", "Includes"}], " ", "all", " ", "three", 
          " ", "calcium", " ", 
          RowBox[{"channels", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"mA", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mAinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"mA", "[", "t", "]"}]}], ")"}], "/", 
          RowBox[{"taumA", "[", 
           RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "activation", " ", "of", " ", "iA"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"mA", "[", "0", "]"}], "\[Equal]", "mA0"}], ",", " ", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"hA", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"hAinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"hA", "[", "t", "]"}]}], ")"}], "/", "tauhA"}]}], ",", 
        " ", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iA"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"hA", "[", "0", "]"}], "\[Equal]", "hA0"}], ",", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"mH", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mHinfin", "[", 
             RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
            RowBox[{"mH", "[", "t", "]"}]}], ")"}], "/", 
          RowBox[{"taumH", "[", 
           RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
          RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iA"}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"mH", "[", "0", "]"}], "\[Equal]", "mH0"}], ",", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"Hodgkin", "-", 
            RowBox[{"Huxley", " ", 
             RowBox[{"formula", ".", " ", "Add"}], " ", "all", " ", "of", " ",
              "the", " ", "voltages", " ", 
             RowBox[{"(", 
              RowBox[{"including", " ", "iLeak"}], ")"}]}]}], ",", " ", 
           RowBox[{"plus", " ", "the", " ", "injected", " ", "current"}]}], 
          " ", "*)"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "cm"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"iNa", "[", 
                 RowBox[{
                  RowBox[{"v", "[", "t", "]"}], ",", 
                  RowBox[{"mNa", "[", "t", "]"}], ",", 
                  RowBox[{"hNa", "[", "t", "]"}]}], "]"}], "+", 
                RowBox[{"ileak", "[", 
                 RowBox[{"v", "[", "t", "]"}], "]"}], "+", 
                RowBox[{"iNaP", "[", 
                 RowBox[{
                  RowBox[{"v", "[", "t", "]"}], ",", 
                  RowBox[{"mNaP", "[", "t", "]"}], ",", 
                  RowBox[{"hNaP", "[", "t", "]"}]}], "]"}], "+", 
                RowBox[{"iK", "[", 
                 RowBox[{
                  RowBox[{"v", "[", "t", "]"}], ",", 
                  RowBox[{"n", "[", "t", "]"}]}], "]"}], "+", 
                RowBox[{"iT", "[", 
                 RowBox[{
                  RowBox[{"v", "[", "t", "]"}], ",", 
                  RowBox[{"mT", "[", "t", "]"}], ",", 
                  RowBox[{"hT", "[", "t", "]"}]}], "]"}], "+", 
                RowBox[{"iN", "[", 
                 RowBox[{
                  RowBox[{"v", "[", "t", "]"}], ",", 
                  RowBox[{"mN", "[", "t", "]"}], ",", 
                  RowBox[{"hN", "[", "t", "]"}]}], "]"}], "+", 
                RowBox[{"iP", "[", 
                 RowBox[{
                  RowBox[{"v", "[", "t", "]"}], ",", 
                  RowBox[{"mP", "[", "t", "]"}]}], "]"}], "+", 
                RowBox[{"iSK", "[", 
                 RowBox[{
                  RowBox[{"v", "[", "t", "]"}], ",", 
                  RowBox[{"zSK", "[", "t", "]"}]}], "]"}], "+", 
                RowBox[{"iA", "[", 
                 RowBox[{
                  RowBox[{"v", "[", "t", "]"}], ",", 
                  RowBox[{"mA", "[", "t", "]"}], ",", 
                  RowBox[{"hA", "[", "t", "]"}]}], "]"}], "+", 
                RowBox[{"iH", "[", 
                 RowBox[{
                  RowBox[{"v", "[", "t", "]"}], ",", 
                  RowBox[{"mH", "[", "t", "]"}]}], "]"}]}], ")"}], ")"}]}], 
            "+", 
            RowBox[{"Inj", "[", "t", "]"}]}], ")"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"v", "[", "0", "]"}], "\[Equal]", "v0"}]}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], "/.", 
      "parametersAll"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mNaP", "[", "t", "]"}], ",", 
       RowBox[{"hNaP", "[", "t", "]"}], ",", 
       RowBox[{"mNa", "[", "t", "]"}], ",", 
       RowBox[{"hNa", "[", "t", "]"}], ",", 
       RowBox[{"n", "[", "t", "]"}], ",", 
       RowBox[{"zSK", "[", "t", "]"}], ",", 
       RowBox[{"mP", "[", "t", "]"}], ",", 
       RowBox[{"mN", "[", "t", "]"}], ",", 
       RowBox[{"hN", "[", "t", "]"}], ",", 
       RowBox[{"mT", "[", "t", "]"}], ",", 
       RowBox[{"hT", "[", "t", "]"}], ",", 
       RowBox[{"ca2", "[", "t", "]"}], ",", 
       RowBox[{"mA", "[", "t", "]"}], ",", 
       RowBox[{"hA", "[", "t", "]"}], ",", 
       RowBox[{"mH", "[", "t", "]"}], ",", 
       RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "100"}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{
  3.543707021201804*^9, 3.543707124410056*^9, 3.543708304674209*^9, {
   3.544802272612195*^9, 3.544802462284905*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"mNaP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hNaP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mNa", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hNa", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"zSK", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mN", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hN", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mT", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hT", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"ca2", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mA", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hA", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mH", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{3.54370703011517*^9, 3.543707124410214*^9, 
  3.543707688557849*^9, 3.543707802235298*^9, 3.543708086228705*^9, 
  3.5437083353311377`*^9, 3.543784212409171*^9, 3.543786224304406*^9, 
  3.54378732609556*^9, 3.543787409519347*^9, 3.54378757261448*^9, 
  3.543787732594101*^9, 3.543787770965456*^9, 3.5437905785751867`*^9, 
  3.543790609852066*^9, 3.543831300332694*^9, 3.543838149540711*^9, 
  3.543838348042355*^9, 3.543838825605259*^9, 3.543838902233117*^9, 
  3.543843348767149*^9, 3.543851410357685*^9, 3.543918693791375*^9, 
  3.543944031891376*^9, 3.543960691353931*^9, 3.54401479526025*^9, 
  3.544364785336978*^9, 3.544710283261899*^9, 3.544713488378192*^9, 
  3.54472768647439*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"v", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageAll"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "50"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "50"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "80"}], ",", 
         RowBox[{"-", "50"}]}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", " ", "\"\<Voltage\>\""}], "}"}]}]}], "]"}],
   " ", 
  RowBox[{"(*", 
   RowBox[{"Plot", " ", "of", " ", "voltage"}], "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{
  3.543707041973497*^9, 3.5437071244103518`*^9, {3.544802471138031*^9, 
   3.544802476505311*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd13c8lV8YAHArmWVmZI97r5FRRim9T+al4nJVIg0tq4zMjCRCJKMfElIZ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Voltage\"", TraditionalForm]},
  AxesOrigin->{0, -80.},
  PlotRange->{{0, 50}, {-80, -50}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{3.5437070432148333`*^9, 3.543707124410489*^9, 
  3.5437076912077713`*^9, 3.543707802263129*^9, 3.543708088785722*^9, 
  3.5437083411921186`*^9, 3.5437842124478188`*^9, 3.5437862243383017`*^9, 
  3.543787326149632*^9, 3.543787409591037*^9, 3.543787572670093*^9, 
  3.5437877329460087`*^9, 3.543787771151321*^9, 3.5437905786205797`*^9, 
  3.543790609935467*^9, 3.543831300379987*^9, 3.543838149598736*^9, 
  3.543838348093734*^9, 3.543838825659464*^9, 3.543838902274782*^9, 
  3.543843348835558*^9, 3.5438514104995003`*^9, 3.5439186938597383`*^9, 
  3.543944032060463*^9, 3.54396069146848*^9, 3.544014795311537*^9, 
  3.544364785388846*^9, 3.544710283310153*^9, 3.544713488451476*^9, 
  3.544727686524082*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "This", " ", "does", " ", "not", " ", "appear", " ", "like", " ", "Figure", 
   " ", "1."}], "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.543707084049757*^9, 3.543707124410626*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(* Examining voltage and state variables. Finding point of stability *)\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543707129552205*^9, 3.543707156605723*^9}, {
  3.5437096386892223`*^9, 3.5437096863535633`*^9}},
 FontSize->16,
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
(* Code here was collaborated with Elena and Julia. We removed the stimulus \
under the instruction of Dr. Chiel. *)\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5448025024444304`*^9, 3.5448025404081907`*^9}, 
   3.544802771211363*^9}],

Cell["\<\
(* Use same parameters and initial conditions. Look at new NDSolve when Inj \
(Istim) is removed. If voltage is stable, we should see a straight line *)\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5437072622995167`*^9, 3.5437073114342537`*^9}, 
   3.543709686353701*^9}],

Cell[BoxData[
 RowBox[{"solutionVoltageNoStim", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"mNa", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"minfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mNa", "[", "t", "]"}]}], ")"}], "/", "tauM"}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "INa"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mNa", "[", "0", "]"}], "\[Equal]", "mNa0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hNa", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hNa", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"tauH", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inaction", " ", "of", " ", "INa"}]}], " ",
         "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hNa", "[", "0", "]"}], "\[Equal]", "hNa0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mNaP", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mNaPinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mNaP", "[", "t", "]"}]}], ")"}], "/", "taumNaP"}]}], ",", 
       
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "INaP"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mNaP", "[", "0", "]"}], "\[Equal]", "mNaP0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hNaP", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hNaPinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hNaP", "[", "t", "]"}]}], ")"}], "/", "tauhNaP"}]}], ",", 
       " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "INaP"}]}],
         " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hNaP", "[", "0", "]"}], "\[Equal]", "hNaP0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"n", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ninfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"n", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"tauN", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", 
          RowBox[{"(", "in", ")"}], "activation", " ", "of", " ", "Ik"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"n", "[", "0", "]"}], "\[Equal]", "n0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mT", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mTinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mT", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"taumt", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "iT"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mT", "[", "0", "]"}], "\[Equal]", "mT0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hT", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hTinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hT", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"tauht", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iT"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hT", "[", "0", "]"}], "\[Equal]", "hT0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mN", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mNinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mN", "[", "t", "]"}]}], ")"}], "/", "taumN"}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "iN"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mN", "[", "0", "]"}], "\[Equal]", "mN0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hN", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hNinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hN", "[", "t", "]"}]}], ")"}], "/", "tauhN"}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iN"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hN", "[", "0", "]"}], "\[Equal]", "hN0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mP", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mPinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mP", "[", "t", "]"}]}], ")"}], "/", "taumP"}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "iP"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mP", "[", "0", "]"}], "\[Equal]", "mP0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"zSK", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zSKinfin", "[", 
            RowBox[{"ca2", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"zSK", "[", "t", "]"}]}], ")"}], "/", "tauzSK"}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "calcium"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "iSK"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"zSK", "[", "0", "]"}], "\[Equal]", "zSK0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ca2", "'"}], "[", "t", "]"}], "\[Equal]", " ", 
        RowBox[{
         RowBox[{"k1", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"gT", "*", 
              RowBox[{"mT", "[", "t", "]"}], "*", 
              RowBox[{"hT", "[", "t", "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], "-", "eCa"}], ")"}]}], ")"}], 
            "+", 
            RowBox[{"(", 
             RowBox[{"gN", "*", 
              RowBox[{"mN", "[", "t", "]"}], "*", 
              RowBox[{"hN", "[", "t", "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], "-", "eCa"}], ")"}]}], ")"}], 
            "+", 
            RowBox[{"(", 
             RowBox[{"gP", "*", 
              RowBox[{"mP", "[", "t", "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], "-", "eCa"}], ")"}]}], ")"}]}], 
           ")"}]}], "-", 
         RowBox[{"k2", "*", 
          RowBox[{"ca2", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ca2", "[", "0", "]"}], "\[Equal]", "ca20"}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
        "solving", " ", "for", " ", "calcium", " ", "concentration", " ", 
         "within", " ", "the", " ", 
         RowBox[{"cell", ".", " ", "Includes"}], " ", "all", " ", "three", 
         " ", "calcium", " ", 
         RowBox[{"channels", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mA", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mAinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mA", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"taumA", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "iA"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mA", "[", "0", "]"}], "\[Equal]", "mA0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hA", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hAinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hA", "[", "t", "]"}]}], ")"}], "/", "tauhA"}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iA"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hA", "[", "0", "]"}], "\[Equal]", "hA0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mH", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mHinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mH", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"taumH", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iA"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mH", "[", "0", "]"}], "\[Equal]", "mH0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"Hodgkin", "-", 
           RowBox[{"Huxley", " ", 
            RowBox[{"formula", ".", " ", "Add"}], " ", "all", " ", "of", " ", 
            "the", " ", "voltages", " ", 
            RowBox[{"(", 
             RowBox[{"including", " ", "iLeak"}], ")"}]}]}], ",", " ", 
          RowBox[{"without", " ", "the", " ", "injected", " ", "current"}]}], 
         " ", "*)"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", "cm"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"iNa", "[", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], ",", 
                RowBox[{"mNa", "[", "t", "]"}], ",", 
                RowBox[{"hNa", "[", "t", "]"}]}], "]"}], "+", 
              RowBox[{"iNaP", "[", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], ",", 
                RowBox[{"mNaP", "[", "t", "]"}], ",", 
                RowBox[{"hNaP", "[", "t", "]"}]}], "]"}], "+", 
              RowBox[{"iA", "[", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], ",", 
                RowBox[{"mA", "[", "t", "]"}], ",", 
                RowBox[{"hA", "[", "t", "]"}]}], "]"}], "+", 
              RowBox[{"iH", "[", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], ",", 
                RowBox[{"mH", "[", "t", "]"}]}], "]"}], "+", "   ", 
              RowBox[{"iSK", "[", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], ",", 
                RowBox[{"zSK", "[", "t", "]"}]}], "]"}], " ", "+", " ", 
              RowBox[{"iK", "[", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], ",", 
                RowBox[{"n", "[", "t", "]"}]}], "]"}], "+", 
              RowBox[{"iT", "[", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], ",", 
                RowBox[{"mT", "[", "t", "]"}], ",", 
                RowBox[{"hT", "[", "t", "]"}]}], "]"}], "+", 
              RowBox[{"iP", "[", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], ",", 
                RowBox[{"mP", "[", "t", "]"}]}], "]"}], "+", 
              RowBox[{"iN", "[", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], ",", 
                RowBox[{"mN", "[", "t", "]"}], ",", 
                RowBox[{"hN", "[", "t", "]"}]}], "]"}], "+", 
              RowBox[{"ileak", "[", 
               RowBox[{"v", "[", "t", "]"}], "]"}]}], ")"}], ")"}]}], 
          RowBox[{"(*", " ", 
           RowBox[{"+", " ", 
            RowBox[{"Inj", "[", "t", "]"}]}], "*)"}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"v", "[", "0", "]"}], "\[Equal]", "v0"}]}], 
      "\[IndentingNewLine]", "}"}], " ", "/.", "parametersAll"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mNaP", "[", "t", "]"}], ",", 
      RowBox[{"hNaP", "[", "t", "]"}], ",", 
      RowBox[{"mNa", "[", "t", "]"}], ",", 
      RowBox[{"hNa", "[", "t", "]"}], ",", 
      RowBox[{"n", "[", "t", "]"}], ",", 
      RowBox[{"mT", "[", "t", "]"}], ",", 
      RowBox[{"hT", "[", "t", "]"}], ",", 
      RowBox[{"mN", "[", "t", "]"}], ",", 
      RowBox[{"hN", "[", "t", "]"}], ",", 
      RowBox[{"mP", "[", "t", "]"}], ",", 
      RowBox[{"mA", "[", "t", "]"}], ",", 
      RowBox[{"hA", "[", "t", "]"}], ",", "  ", 
      RowBox[{"zSK", "[", "t", "]"}], ",", " ", 
      RowBox[{"ca2", "[", "t", "]"}], ",", "  ", 
      RowBox[{"mH", "[", "t", "]"}], ",", 
      RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543707331703149*^9, 3.543707366340617*^9}, 
   3.54370835275438*^9, {3.54370850219611*^9, 3.5437085145977783`*^9}, 
   3.543709686353848*^9, 3.544802580784505*^9, {3.5448027472227182`*^9, 
   3.544802748763461*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"mNaP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hNaP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mNa", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hNa", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mT", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hT", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mN", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hN", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mA", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hA", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"zSK", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"ca2", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mH", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.54370734094923*^9, 3.543707367412005*^9}, 
   3.543707700846677*^9, 3.543707802372426*^9, 3.543708091484066*^9, 
   3.543708440468848*^9, 3.543708523082561*^9, 3.5437096863540077`*^9, 
   3.5437842127471313`*^9, 3.543786224449627*^9, 3.543787326394532*^9, 
   3.543787409977625*^9, 3.54378757283184*^9, 3.543787733169445*^9, 
   3.543787771426435*^9, 3.543790578718153*^9, 3.543790610281073*^9, 
   3.5438313005296*^9, 3.543838149720429*^9, 3.5438383482151337`*^9, 
   3.543838825834732*^9, 3.5438389023946857`*^9, 3.543843349193103*^9, 
   3.543851410631215*^9, 3.543918694023114*^9, 3.543944032261882*^9, 
   3.54396069160922*^9, 3.544014795505069*^9, 3.544364785566126*^9, 
   3.544710283536255*^9, 3.544713488685378*^9, 3.544727686758381*^9, 
   3.544802582863571*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Code", " ", "for", " ", "testing", " ", "stability", " ", "was", " ", 
   "collaborative"}], " ", "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.544802606604686*^9, 3.544802622203106*^9}, 
   3.544802771211505*^9}],

Cell[BoxData[
 RowBox[{"graphNoStim", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"v", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "80"}], ",", 
         RowBox[{"-", "70"}]}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (mS)\>\"", ",", " ", "\"\<Voltage (mV)\>\""}], 
      "}"}]}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Graph", " ", "of", " ", "voltage", " ", "without", " ", 
    RowBox[{"stimulus", ".", " ", "Not"}], " ", 
    RowBox[{"stable", "."}]}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5437073858149157`*^9, 3.543707390111672*^9}, {
   3.543707489887673*^9, 3.543707496188739*^9}, {3.543707857065517*^9, 
   3.5437078747354803`*^9}, {3.543707966518902*^9, 3.5437080011155252`*^9}, 
   3.543708127335375*^9, {3.5437085354329433`*^9, 3.5437085784708033`*^9}, {
   3.543708787122038*^9, 3.543708802696003*^9}, 3.543709686354164*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl13c8VW8cB3CbsqUUkpkSDZKM8qUyiriuoiIhKpFrhJCVdZG9s/csQknG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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Voltage (mV)\"", TraditionalForm]},
  AxesOrigin->{0, -80.},
  ImageSize->{381., Automatic},
  PlotRange->{{0, 10000}, {-80, -70}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{
  3.543707496837318*^9, 3.5437077035713463`*^9, 3.543707802498291*^9, 
   3.5437078753971024`*^9, {3.5437079694757137`*^9, 3.54370800179504*^9}, 
   3.5437080960092573`*^9, 3.5437081279559383`*^9, 3.543708443357562*^9, {
   3.543708519922277*^9, 3.543708548381968*^9}, 3.5437085792345667`*^9, 
   3.5437096863543053`*^9, 3.5437842128016033`*^9, 3.543786224474489*^9, 
   3.543787326591559*^9, 3.543787410072604*^9, 3.543787573117165*^9, 
   3.543787733239101*^9, 3.543787771481106*^9, 3.543790578766344*^9, 
   3.543790610377302*^9, 3.543831300578312*^9, 3.543838149764408*^9, 
   3.543838348294598*^9, 3.543838825896852*^9, 3.54383890245781*^9, 
   3.543843349388978*^9, 3.5438514106841183`*^9, 3.543918694344529*^9, 
   3.543944032363801*^9, 3.543960691650578*^9, 3.544014795548408*^9, 
   3.544364785623406*^9, 3.544710283592573*^9, 3.544713489527816*^9, 
   3.54472768680826*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "The", " ", "following", " ", "plots", " ", "map", " ", "the", " ", 
   "change", " ", "in", " ", "the", " ", "activation", " ", "and", " ", 
   "inactivation", " ", "functions", " ", "when", " ", "there", " ", "is", 
   " ", "no", " ", 
   RowBox[{"stimulation", ".", " ", "We"}], " ", "estimated", " ", "when", 
   " ", "these", " ", "plots", " ", "reached", " ", "relative", " ", 
   "stability"}], " ", "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.544802640083733*^9, 3.5448026978322287`*^9}, {
  3.544802737392188*^9, 3.544802771211626*^9}}],

Cell[BoxData[
 RowBox[{"graphSK", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"zSK", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (mS)\>\"", ",", " ", "\"\<Voltage (mV)\>\""}], 
      "}"}]}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Graph", " ", "of", " ", "zSK"}], "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543708612505988*^9, 3.5437086385658627`*^9}, {
   3.5437088098712807`*^9, 3.54370882410281*^9}, 3.543709686354446*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1Hk41dkbAHBLVHZFyZjsjVRki7R40yI0WUdG+CFuQ0yUVCprCGUpxbXd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     "]], 
    LineBox[{{0.006109452761567477, 0.002033593258078989}, {
     0.006112798496060492, 0.0020346300845846058`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Voltage (mV)\"", TraditionalForm]},
  AxesOrigin->{0, 0.0020336},
  PlotRange->{{0, 10000}, {0.002033593258078989, 0.0020346300845846058`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543708626538032*^9, 3.543708639009179*^9}, 
   3.543709686354588*^9, 3.5437842129378357`*^9, 3.543786224533621*^9, 
   3.543787326663533*^9, 3.54378741015033*^9, 3.54378757318894*^9, 
   3.543787733300179*^9, 3.543787771547274*^9, 3.5437905788208857`*^9, 
   3.543790610433875*^9, 3.5438313006496*^9, 3.5438381498300753`*^9, 
   3.543838348365097*^9, 3.543838826030407*^9, 3.543838902527978*^9, 
   3.543843349456901*^9, 3.543851410855297*^9, 3.543918694457221*^9, 
   3.543944032469206*^9, 3.543960691720852*^9, 3.544014795664218*^9, 
   3.5443647857816*^9, 3.544710283733444*^9, 3.544713489818131*^9, 
   3.544727686949719*^9}],

Cell[BoxData[
 RowBox[{"graphca2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"ca2", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (mS)\>\"", ",", " ", "\"\<Voltage (mV)\>\""}], 
      "}"}]}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{"Graph", " ", "of", " ", "ca2"}], "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543708650453485*^9, 3.543708660220107*^9}, {
   3.543708832033008*^9, 3.543708836870266*^9}, 3.543709686354726*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl0nk81FsbAPBR2bLvwsUIRZElCW9vD5KSkiWpKIS33LpNKeFm30I3bsQM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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Voltage (mV)\"", TraditionalForm]},
  AxesOrigin->{0, 0.000135437},
  PlotRange->{{0, 10000}, {0.00013543687917050333`, 0.0001354618084340258}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.543708662404216*^9, 3.543709686354868*^9, 
  3.5437842129935493`*^9, 3.543786224792742*^9, 3.543787326735857*^9, 
  3.543787410211832*^9, 3.543787573251711*^9, 3.5437877333545637`*^9, 
  3.5437877716158037`*^9, 3.543790578864316*^9, 3.543790610528298*^9, 
  3.5438313007148113`*^9, 3.543838149905726*^9, 3.543838348445396*^9, 
  3.54383882609235*^9, 3.543838902585195*^9, 3.5438433495419397`*^9, 
  3.5438514109584084`*^9, 3.543918694563389*^9, 3.543944032561891*^9, 
  3.543960691787516*^9, 3.544014795785222*^9, 3.54436478587613*^9, 
  3.544710283844241*^9, 3.544713489932405*^9, 3.544727687075225*^9}],

Cell[BoxData[
 RowBox[{"graphmNa", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"mNa", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (mS)\>\"", ",", " ", "\"\<Voltage (mV)\>\""}], 
      "}"}]}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
   "Graph", " ", "of", " ", "graph", " ", "of", " ", "activation", " ", "Na", 
    " ", "current"}], "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5437086850842247`*^9, 3.543708705836532*^9}, {
   3.5437088408072*^9, 3.543708846309958*^9}, {3.543709386195374*^9, 
   3.543709391531159*^9}, {3.543709515182687*^9, 3.543709517391053*^9}, 
   3.5437096863550043`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl0Hk01FscAHCUJWsiyntFtiQpSxH1fEdaFA0RXtGLNK1qQptk35Wl1BPG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     "]], 
    LineBox[{{0.035713017245764825`, 0.01489598482094261}, {
     0.036627214543288655`, 0.014893331835839057`}}], 
    LineBox[{{131.49959356418125`, 0.014893331835839057`}, {131.5629742595386,
      0.01489598482094261}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Voltage (mV)\"", TraditionalForm]},
  AxesOrigin->{0, 0.0148933},
  PlotRange->{{0, 10000}, {0.014893331835839057`, 0.01489598482094261}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543708701956081*^9, 3.543708706854909*^9}, 
   3.5437096863551493`*^9, 3.543784213053315*^9, 3.543786224844232*^9, 
   3.543787326824641*^9, 3.543787410283297*^9, 3.5437875733076143`*^9, 
   3.543787733417366*^9, 3.5437877716946507`*^9, 3.5437905789149303`*^9, 
   3.5437906105843773`*^9, 3.5438313007819767`*^9, 3.543838149962288*^9, 
   3.543838348527727*^9, 3.5438388263304787`*^9, 3.5438389026403437`*^9, 
   3.543843349630712*^9, 3.543851411074574*^9, 3.543918695019926*^9, 
   3.5439440326299667`*^9, 3.5439606919363527`*^9, 3.544014795991355*^9, 
   3.544364785975761*^9, 3.544710283976334*^9, 3.544713490083334*^9, 
   3.5447276871976843`*^9}],

Cell[BoxData[
 RowBox[{"graphhNa", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"hNa", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (mS)\>\"", ",", " ", "\"\<Voltage (mV)\>\""}], 
      "}"}]}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
   "Graph", " ", "of", " ", "graph", " ", "of", " ", "inactivation", " ", 
    "Na", " ", "current"}], "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543708710853752*^9, 3.543708725657894*^9}, {
   3.5437088494784813`*^9, 3.543708859109498*^9}, {3.543709379475588*^9, 
   3.543709382683666*^9}, {3.543709508511258*^9, 3.543709512174961*^9}, 
   3.543709686355348*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt0Xs4FNgbB3CXUDRuiVZCoVAqNBS77UtbqRRKUuHnli6bogvSBQlNKhVb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     "]], 
    LineBox[{{133.30567005151923`, 0.9807905020798695}, {133.38069909879337`, 
     0.980785867207862}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Voltage (mV)\"", TraditionalForm]},
  AxesOrigin->{0, 0.9807857999999999},
  PlotRange->{{0, 10000}, {0.980785867207862, 0.9807905020798695}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.54370872689664*^9, 3.5437096863554907`*^9, 
  3.543784213221201*^9, 3.543786224893588*^9, 3.5437873269130373`*^9, 
  3.543787410332608*^9, 3.543787573367387*^9, 3.543787733487743*^9, 
  3.5437877717561083`*^9, 3.5437905789734592`*^9, 3.543790610647358*^9, 
  3.543831300940344*^9, 3.543838150020509*^9, 3.543838348587777*^9, 
  3.543838826436466*^9, 3.5438389027203693`*^9, 3.5438433497056017`*^9, 
  3.543851411176474*^9, 3.5439186951748667`*^9, 3.543944032700788*^9, 
  3.543960692003517*^9, 3.544014796092333*^9, 3.5443647860751534`*^9, 
  3.544710284188636*^9, 3.5447134901972437`*^9, 3.5447276873280993`*^9}],

Cell[BoxData[
 RowBox[{"graphmNaP", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"mNaP", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (mS)\>\"", ",", " ", "\"\<Voltage (mV)\>\""}], 
      "}"}]}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
   "Graph", " ", "of", " ", "graph", " ", "of", " ", "activation", " ", "NaP",
     " ", "current"}], "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543708746778191*^9, 3.543708757488797*^9}, {
   3.543708881877569*^9, 3.5437088875166283`*^9}, {3.543709365388425*^9, 
   3.5437093713879633`*^9}, {3.5437095028714533`*^9, 3.543709505231247*^9}, 
   3.543709686355629*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl0Hk81dkbB3ARSnTtpMUuTBGmFJWHSiqlMNroZ59UQrTLGrIUSuJa7n5t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     "]], 
    LineBox[{{131.49794840416808`, 0.0025147209284811537`}, {
     131.56165569907898`, 0.0025156627300699968`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Voltage (mV)\"", TraditionalForm]},
  AxesOrigin->{0, 0.00251475},
  PlotRange->{{0, 10000}, {0.0025147209284811537`, 0.0025156627300699968`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.543708758245029*^9, 3.543709686355782*^9, 
  3.543784213298395*^9, 3.543786224974609*^9, 3.543787326977324*^9, 
  3.543787410394733*^9, 3.543787573438266*^9, 3.543787733549798*^9, 
  3.543787771827059*^9, 3.543790579031764*^9, 3.5437906107046947`*^9, 
  3.5438313010267*^9, 3.543838150078689*^9, 3.543838348661169*^9, 
  3.543838826663383*^9, 3.5438389027925863`*^9, 3.54384334976645*^9, 
  3.543851411324785*^9, 3.543918695285754*^9, 3.54394403276388*^9, 
  3.543960692124168*^9, 3.5440147961911*^9, 3.544364786157165*^9, 
  3.544710284313278*^9, 3.5447134903501472`*^9, 3.544727687448244*^9}],

Cell[BoxData[
 RowBox[{"graphhNaP", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"hNaP", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (mS)\>\"", ",", " ", "\"\<Voltage (mV)\>\""}], 
      "}"}]}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
   "Graph", " ", "of", " ", "inactivation", " ", "NaP", " ", "current"}], 
   "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5437087632263517`*^9, 3.543708773528145*^9}, {
   3.543708891828986*^9, 3.5437088963881598`*^9}, {3.5437093577564383`*^9, 
   3.5437093603880997`*^9}, {3.543709495511486*^9, 3.5437095003033247`*^9}, 
   3.543709686355919*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl0nk019kbB3AUIvsayhZFikFKKA9aGCQSmlAUM0xCKLRYUvaklOUX331D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     "]], 
    LineBox[{{417.5658802515659, 0.7901953745502874}, {418.4951585678248, 
     0.7901525025125169}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Voltage (mV)\"", TraditionalForm]},
  AxesOrigin->{0, 0.790152},
  PlotRange->{{0, 10000}, {0.7901525025125169, 0.7901953745502874}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.543708774218854*^9, 3.54370968635607*^9, 
  3.543784213351574*^9, 3.5437862250286283`*^9, 3.5437873270726852`*^9, 
  3.543787410465345*^9, 3.543787573504409*^9, 3.5437877336034727`*^9, 
  3.543787771899688*^9, 3.543790579102254*^9, 3.543790610761891*^9, 
  3.543831301083548*^9, 3.543838150151972*^9, 3.543838348753599*^9, 
  3.543838826747793*^9, 3.5438389028546333`*^9, 3.543843349866205*^9, 
  3.543851411424356*^9, 3.543918695410894*^9, 3.5439440328297977`*^9, 
  3.543960692185164*^9, 3.544014796293385*^9, 3.544364786224325*^9, 
  3.544710286038707*^9, 3.544713490470851*^9, 3.544727687576951*^9}],

Cell[BoxData[
 RowBox[{"graphK", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"n", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (mS)\>\"", ",", " ", "\"\<Voltage (mV)\>\""}], 
      "}"}]}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"Graph", " ", "of", " ", "delayed"}], "-", 
     RowBox[{"rect", " ", "potassium", " ", "current"}]}], ",", " ", 
    RowBox[{"n", "[", "t", "]"}]}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5437089218501577`*^9, 3.54370898529768*^9}, 
   3.543709686356207*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl0nk8VVsbB3B0zUkqKrfMSgrF21VSHprMJ0MowzWerkohyVCEJHMimY4z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     "]], 
    LineBox[{{132.3774907114557, 0.15906191077861687`}, {132.44780970192141`, 
     0.15907019944201095`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Voltage (mV)\"", TraditionalForm]},
  AxesOrigin->{0, 0.15906199999999998`},
  PlotRange->{{0, 10000}, {0.15906191077861687`, 0.15907019944201095`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.5437089323430557`*^9, 3.543709686356352*^9, 
  3.543784213428067*^9, 3.54378622507419*^9, 3.543787327143292*^9, 
  3.54378741052778*^9, 3.54378757355363*^9, 3.5437877336535482`*^9, 
  3.5437877719567633`*^9, 3.543790579169479*^9, 3.5437906108129673`*^9, 
  3.543831301147029*^9, 3.543838150210598*^9, 3.543838348806857*^9, 
  3.5438388268013697`*^9, 3.543838902961252*^9, 3.5438433499464903`*^9, 
  3.543918695519683*^9, 3.543944032894931*^9, 3.543960692251917*^9, 
  3.544014796390264*^9, 3.544364786323011*^9, 3.544710287353833*^9, 
  3.544713490570118*^9, 3.544727687766371*^9}],

Cell[BoxData[
 RowBox[{"graphmT", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"mT", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", " ", "\"\<Voltage\>\""}], "}"}]}]}], "]"}],
   " ", 
  RowBox[{"(*", 
   RowBox[{
   "graph", " ", "of", " ", "activation", " ", "of", " ", "T", " ", 
    "current"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543709040581976*^9, 3.543709078045788*^9}, 
   3.543709686356488*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1Hk8lNsbAPBBKKVBmm5ys5SS0qYo6npsRUghlegXaX4oRVlS2UMoW24J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     "]], 
    LineBox[{{136.36793222287608`, 0.0011977379736968496`}, {
     136.43466393214592`, 0.0011981066374178858`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Voltage\"", TraditionalForm]},
  AxesOrigin->{0, 0.00119774},
  PlotRange->{{0, 10000}, {0.0011977379736968496`, 0.0011981066374178858`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.543709058720523*^9, 3.543709686356633*^9, 
  3.543784213500189*^9, 3.543786225121873*^9, 3.543787327194117*^9, 
  3.543787410598648*^9, 3.543787573599279*^9, 3.5437877337036858`*^9, 
  3.543787772043709*^9, 3.543790579217903*^9, 3.543790610879691*^9, 
  3.5438313012221937`*^9, 3.543838150374344*^9, 3.543838348867482*^9, 
  3.543838826852763*^9, 3.543838903017701*^9, 3.543843350070492*^9, 
  3.543918695618421*^9, 3.5439440330246687`*^9, 3.543960692397439*^9, 
  3.544014796489271*^9, 3.544364786384904*^9, 3.544710287542262*^9, 
  3.5447134907684193`*^9, 3.5447276878904133`*^9}],

Cell[BoxData[
 RowBox[{"graphhT", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"hT", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", " ", "\"\<Voltage\>\""}], "}"}]}]}], "]"}],
   " ", 
  RowBox[{"(*", 
   RowBox[{
   "graph", " ", "of", " ", "inactivation", " ", "of", " ", "T", " ", 
    "current"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543709085703895*^9, 3.543709110796701*^9}, 
   3.543709686356769*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1Xk8VdsXAHCEUuaxJMlQnl4UlUK1kAaUSPQTvRS3eAkZiwxJQhHJcA33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     "]], 
    LineBox[{{146.78114170432286`, 0.5544479133821423}, {146.84340968126747`, 
     0.5543934784642663}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Voltage\"", TraditionalForm]},
  AxesOrigin->{0, 0.5543939999999999},
  PlotRange->{{0, 10000}, {0.5543934784642663, 0.5544479133821423}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.5437091117221317`*^9, 3.543709686356906*^9, 
  3.543784213563199*^9, 3.54378622517393*^9, 3.543787327255589*^9, 
  3.543787410664447*^9, 3.543787573649213*^9, 3.5437877338593884`*^9, 
  3.543787772211915*^9, 3.543790579292727*^9, 3.5437906109447727`*^9, 
  3.543831301279695*^9, 3.5438381504277077`*^9, 3.543838348952218*^9, 
  3.543838826906281*^9, 3.543838903081032*^9, 3.543843350137712*^9, 
  3.543918695984074*^9, 3.5439440330783243`*^9, 3.543960692473126*^9, 
  3.544014796589856*^9, 3.544364786452908*^9, 3.544710287665133*^9, 
  3.54471349087092*^9, 3.5447276892740297`*^9}],

Cell[BoxData[
 RowBox[{"graphmP", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"mP", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", " ", "\"\<Voltage\>\""}], "}"}]}]}], "]"}],
   " ", 
  RowBox[{"(*", 
   RowBox[{
   "graph", " ", "of", " ", "activation", " ", "of", " ", "P", " ", 
    "current"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5437091331751137`*^9, 3.5437091775943108`*^9}, 
   3.543709686357052*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl0XlQU1cUB+CA7AKyiBWLrBZRq1NpIYW2cBAiEBhBJqUyLMqWEYuARRCR
yBC2EiohhaGCLAGbkAgNYJQlCCRcMkgrI1VA0cpQW6BgU6UsHZbWvnffH3fu
fHPmd885cx3iUsMStWk0WghxyFvv/JsA4elaEAfcj9nMZ3rtcN6jiq2uhXu2
djnzhIcMs0WTPvVgoCOv5xDO0kyVBC02wMudgZaehGHi6pHjvUKQePOY5oTV
crPr7LxGcPSLylvjMr0W7Tvpjb5N0GJddmCWsGlZ5JPnujchfp4vniLcP3rp
YPXTmxDlG8n9mfB5k0pOeMv3cIrpEfKA8LCHxf31VBEojZxcRgg7sMst6j4S
w37nDbNhwnqJhWbIsBmC/yisUhN+FZ9tujDdDMYmXNEQ4bQl7rED7RK4YeBo
Rnr1amlmUp4Uyr4KbEeE962vNvL9bgEjYiaTNCv9zOhd/RaoUluHkDZV+rTG
PG8BmxsRR0mPGDuV6re1QuqUqS3pI8fZsVUXf4Aea7YF6YpcKf09TxmkT0Zt
J/13yD9oAmQgj3sfO8yeEVrkL4OH9C0j0uaqmbPzLBkwv67F5mvvrpGmysCe
NW1IurSwaOuwSAavZBkGpPNL41XuZm0wM6PUI53+3d6ggLk22CmY1iHNZEfN
hqjbgf95pRbpAk1pbWxJB8Sdzv5vkHCgv6v+WvRtiA7ibJHuueaZlLZPDpme
odgjceFauvNy4PxYh51gtBBso7gDXeeMcF5a/4JvnXsXvHkr/5K+rBtYVM3q
BGF5Kq4vbAzf/tC5C7y4bFzf9kIyKV/oAoFiCr8nFdBknX3dUFHogr3uqshp
yO8BxcrjTZyPK85rYihg5ZsJ7ITEnzxcdvfCow9msUtYFxYqfumF1iBvnPfY
VRbM7bgHQishduWQcXN4Vh9IXlPz87Ua6IxP+mHUMhHbylxypdN0AE7k8rAZ
JpZdJuMDUG4vxqalbDxaZilh0CkGW2aTMavpU8JfcnfsDpVw+ZmdCjQvXbE3
HhZHGvJU8LGbM/b1cbuBgxoVfHpyB3aRUPVZxIlBeH1LG1sxYbtrpGsQLoje
4n18tQ4vHtqDwCaZMvtakudv7yJIy6DMsxbzavYiCMqlPHbU7pChA4LqSspR
cebJc/sRPFVTvohWNUI3BGo/Gu4nLuxfsjqJQIC0qP813/QZDUMw+ivlP+vo
3xawEIzTqPlcO9tdl78g+vlQ7p9rSh+LQWD7gPIT/+JVXjIC+nYdav/HiHEs
BYELnbLtGVrVeioCvQTKCVmX3c+mI6hUUn4j+fISIxuBW6EutqWbZHjrCoKx
bsruqt/fucNBcE5DOWcqutsxD4EoQg+7IbHG4BkXQaCA8uDS5ClBAYK1Ecqz
HEtpQBGC1m362AZGoetvixGkeFH+H6H3ZXU=
     "]], 
    LineBox[{{143.75040385580826`, 1.234371576370271*^-8}, {143.7866839312862,
      1.2347267174871405`*^-8}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Voltage\"", TraditionalForm]},
  AxesOrigin->{0, 1.23437*^-8},
  PlotRange->{{0, 10000}, {1.234371576370271*^-8, 1.2347267174871405`*^-8}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.5437091781894836`*^9, 3.543709686357189*^9, 
  3.54378421375972*^9, 3.543786225219713*^9, 3.5437873273037367`*^9, 
  3.543787410726654*^9, 3.54378757370291*^9, 3.543787733914321*^9, 
  3.543787772269552*^9, 3.543790579375909*^9, 3.5437906110145187`*^9, 
  3.54383130135093*^9, 3.5438381504761257`*^9, 3.543838349021476*^9, 
  3.543838826968135*^9, 3.543838903150316*^9, 3.5438433502174187`*^9, 
  3.5439186960992937`*^9, 3.543944033132262*^9, 3.54396069253554*^9, 
  3.544014796715028*^9, 3.5443647865440817`*^9, 3.544710287771316*^9, 
  3.544713490990484*^9, 3.5447276906448*^9}],

Cell[BoxData[
 RowBox[{"graphmN", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"mN", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", " ", "\"\<Voltage\>\""}], "}"}]}]}], "]"}],
   " ", 
  RowBox[{"(*", 
   RowBox[{
   "graph", " ", "of", " ", "activation", " ", "of", " ", "N", " ", 
    "current"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.54370924044902*^9, 3.5437092630473967`*^9}, 
   3.543709686357334*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1Hk01PsbB3ASSlkGUSp7FEWRhLoepFRqioku6YYxvyI11uSKpJJUWlSW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     "]], 
    LineBox[{{0.3450485866970503, 0.0009690988805540954}, {0.3478909058507318,
      0.0009688442056148495}}], 
    LineBox[{{137.07540066091323`, 0.0009688442056148495}, {
     137.14149933475028`, 0.0009690988805540954}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Voltage\"", TraditionalForm]},
  AxesOrigin->{0, 0.00096884},
  PlotRange->{{0, 10000}, {0.0009688442056148495, 0.0009690988805540954}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.543709254620675*^9, 3.543709686357471*^9, 
  3.543784213852231*^9, 3.5437862252719183`*^9, 3.5437873273605556`*^9, 
  3.543787410908059*^9, 3.5437875737687683`*^9, 3.543787733985519*^9, 
  3.543787772342531*^9, 3.543790579429237*^9, 3.543790611176796*^9, 
  3.543831301412408*^9, 3.5438381505263023`*^9, 3.543838349086993*^9, 
  3.543838827037265*^9, 3.5438389032314053`*^9, 3.5438433506593523`*^9, 
  3.543918696242608*^9, 3.543944033193153*^9, 3.5439606926015053`*^9, 
  3.544014796863639*^9, 3.5443647866513844`*^9, 3.5447102880266533`*^9, 
  3.544713491120853*^9, 3.54472769088663*^9}],

Cell[BoxData[
 RowBox[{"graphhN", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"hN", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", " ", "\"\<Voltage\>\""}], "}"}]}]}], "]"}],
   " ", 
  RowBox[{"(*", 
   RowBox[{
   "graph", " ", "of", " ", "inactivation", " ", "of", " ", "N", " ", 
    "current"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543709192790077*^9, 3.5437092336722183`*^9}, 
   3.5437096863576517`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl03k41FsYB3BL9n2XkGyFVpIY6SWKspSkEl2EVFwUJVxrSJKUym7GzJgZ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     "]], 
    LineBox[{{170.93106820751157`, 0.632637097247948}, {171.02033456517498`, 
     0.6325115489622395}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Voltage\"", TraditionalForm]},
  AxesOrigin->{0, 0.63251},
  PlotRange->{{0, 10000}, {0.6325115489622395, 0.632637097247948}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5437092050560503`*^9, 3.543709212330327*^9}, 
   3.54370968635779*^9, 3.543784213930395*^9, 3.543786225324183*^9, 
   3.543787327409246*^9, 3.5437874109804697`*^9, 3.5437875738364677`*^9, 
   3.543787734050632*^9, 3.543787772404768*^9, 3.543790579500535*^9, 
   3.543790611251246*^9, 3.543831301467141*^9, 3.5438381505977488`*^9, 
   3.543838349159668*^9, 3.543838827110387*^9, 3.5438389033048277`*^9, 
   3.543843350735608*^9, 3.543918696348084*^9, 3.543944033265706*^9, 
   3.543960694807043*^9, 3.544014797060853*^9, 3.54436478679567*^9, 
   3.54471028813039*^9, 3.544713491341729*^9, 3.544727691031589*^9}],

Cell[BoxData[
 RowBox[{"graphmA", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"mA", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", " ", "\"\<Voltage\>\""}], "}"}]}]}], "]"}],
   " ", 
  RowBox[{"(*", 
   RowBox[{
   "graph", " ", "of", " ", "activation", " ", "of", " ", "A", " ", 
    "current"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543709292269211*^9, 3.543709345788476*^9}, 
   3.5437096863579283`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl0nk81FsUAHARyq5QqSTbq4RC2SoHRWUZIfVERUypbCUh2bImS6ViDDNj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     "]], 
    LineBox[{{133.2361263924449, 0.057898940518143614`}, {133.3043319510227, 
     0.057904239659577215`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Voltage\"", TraditionalForm]},
  AxesOrigin->{0, 0.057899},
  PlotRange->{{0, 10000}, {0.057898940518143614`, 0.057904239659577215`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.543709339833994*^9, 3.543709686358073*^9, 
  3.5437842140977087`*^9, 3.543786225369445*^9, 3.5437873275766573`*^9, 
  3.543787411044135*^9, 3.54378757403014*^9, 3.543787734120041*^9, 
  3.543787772478573*^9, 3.543790579573957*^9, 3.543790611309396*^9, 
  3.543831301539713*^9, 3.543838150659762*^9, 3.543838349224997*^9, 
  3.543838827190462*^9, 3.543838903367961*^9, 3.5438433507861013`*^9, 
  3.54391869641125*^9, 3.543944033351186*^9, 3.543960696530285*^9, 
  3.544014797120994*^9, 3.544364786854953*^9, 3.5447102882808123`*^9, 
  3.5447134914680433`*^9, 3.5447276911646442`*^9}],

Cell[BoxData[
 RowBox[{"graphhA", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"hA", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", " ", "\"\<Voltage\>\""}], "}"}]}]}], "]"}],
   " ", 
  RowBox[{"(*", 
   RowBox[{
   "graph", " ", "of", " ", "inactivation", " ", "of", " ", "A", " ", 
    "current"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543709418114812*^9, 3.543709433521502*^9}, 
   3.54370968635821*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl0nk41FsYB3AplCVESIWs4VoihMpLGxEtoq5UY5lSuYbsa5TGlqUkMWNm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     "]], 
    LineBox[{{166.24963467880713`, 0.3184610317422717}, {166.32735505961352`, 
     0.3184304605774043}}], 
    LineBox[{{4.269900012615372, 0.3184304605774043}, {4.273630549908274, 
     0.3184610317422717}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Voltage\"", TraditionalForm]},
  AxesOrigin->{0, 0.31843},
  PlotRange->{{0, 10000}, {0.3184304605774043, 0.3184610317422717}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5437094276393213`*^9, 3.54370943418491*^9}, 
   3.543709686358356*^9, 3.5437842141785307`*^9, 3.5437862254198303`*^9, 
   3.5437873277423162`*^9, 3.543787411115777*^9, 3.543787574101288*^9, 
   3.543787734184181*^9, 3.5437877725393457`*^9, 3.543790579629808*^9, 
   3.543790611357337*^9, 3.5438313016105967`*^9, 3.543838150730002*^9, 
   3.543838349285081*^9, 3.543838827255625*^9, 3.543838903441*^9, 
   3.5438433508480377`*^9, 3.543918696482298*^9, 3.543944033448258*^9, 
   3.543960696681583*^9, 3.5440147972096*^9, 3.544364786916114*^9, 
   3.544710288421693*^9, 3.5447134915846252`*^9, 3.544727691302471*^9}],

Cell[BoxData[
 RowBox[{"graphmH", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"mH", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNoStim"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", " ", "\"\<Voltage\>\""}], "}"}]}]}], "]"}],
   " ", 
  RowBox[{"(*", 
   RowBox[{
   "graph", " ", "of", " ", "activation", " ", "of", " ", "H", " ", 
    "current"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5437095433185673`*^9, 3.543709561861002*^9}, 
   3.543709686358492*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1Hc81d0fAHApkhGyVSK0NUgyygcNGhQav9CTdYuUW9GQrLIyWsq917rX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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Voltage\"", TraditionalForm]},
  AxesOrigin->{0, 0.17632},
  PlotRange->{{0, 10000}, {0.1763168464408813, 0.17654738360223143`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{3.543709567116444*^9, 3.543709686358636*^9, 
  3.543784214231039*^9, 3.5437862254680233`*^9, 3.5437873278258343`*^9, 
  3.543787411177651*^9, 3.543787574155693*^9, 3.5437877342498407`*^9, 
  3.5437877726127033`*^9, 3.543790579679264*^9, 3.5437906114174147`*^9, 
  3.543831301681901*^9, 3.5438381507977448`*^9, 3.543838349344356*^9, 
  3.543838827324399*^9, 3.54383890350219*^9, 3.543843350920878*^9, 
  3.543918696543583*^9, 3.543944033515678*^9, 3.5439606967554703`*^9, 
  3.54401479727547*^9, 3.544364786983016*^9, 3.544710288589905*^9, 
  3.544713491695375*^9, 3.5447276914473457`*^9}],

Cell["\<\
(* All 16 state variables appear to be stable when t =6000 ms *)\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.543709578171218*^9, 3.543709610770131*^9}, 
   3.543709691981827*^9, {3.544802713681402*^9, 3.544802727541209*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["(* Finding new initial conditions at t = 6000 ms *)", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.543709745933023*^9, 3.543709784721408*^9}, 
   3.54371008653126*^9},
 FontSize->16,
 Background->RGBColor[1, 0.9, 0.8]],

Cell[BoxData[
 RowBox[{"initialValues", " ", "=", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Find", " ", "value", " ", "of", " ", "16", " ", "state", " ", 
      "variables", " ", "as", " ", "t"}], "=", "6000"}], ",", " ", 
    RowBox[{"use", " ", "replace", " ", 
     RowBox[{"all", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v", "[", "t", "]"}], ",", 
      RowBox[{"mNa", "[", "t", "]"}], ",", 
      RowBox[{"hNa", "[", "t", "]"}], ",", 
      RowBox[{"mNaP", "[", "t", "]"}], ",", 
      RowBox[{"hNaP", "[", "t", "]"}], ",", 
      RowBox[{"n", "[", "t", "]"}], ",", 
      RowBox[{"mT", "[", "t", "]"}], ",", 
      RowBox[{"hT", "[", "t", "]"}], ",", 
      RowBox[{"mP", "[", "t", "]"}], ",", 
      RowBox[{"mN", "[", "t", "]"}], ",", 
      RowBox[{"hN", "[", "t", "]"}], ",", 
      RowBox[{"zSK", "[", "t", "]"}], ",", 
      RowBox[{"mA", "[", "t", "]"}], ",", 
      RowBox[{"hA", "[", "t", "]"}], ",", 
      RowBox[{"mH", "[", "t", "]"}], ",", 
      RowBox[{"ca2", "[", "t", "]"}]}], "}"}], "/.", 
    "solutionVoltageNoStim"}], "/.", 
   RowBox[{"t", "\[Rule]", "6000"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.543709803605032*^9, 3.5437098421823883`*^9}, {
  3.543710077270612*^9, 3.543710086531395*^9}, {3.544802803845111*^9, 
  3.544802816642223*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "71.63003254526362`"}], ",", "0.014894326717078644`", ",", 
    "0.9807887639851169`", ",", "0.002515074108266481`", ",", 
    "0.7901792967899248`", ",", "0.15906501906411205`", ",", 
    "0.0011978762242570837`", ",", "0.5544275000473116`", ",", 
    "1.2345047571399302`*^-8", ",", "0.0009689397098428325`", ",", 
    "0.6325900160848177`", ",", "0.0020339820708956055`", ",", 
    "0.05790092771965761`", ",", "0.31844956741657243`", ",", 
    "0.1763168475925179`", ",", "0.00013543687929309795`"}], "}"}], 
  "}"}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.543709804896385*^9, 3.543709814226192*^9}, {
   3.5437100772707787`*^9, 3.543710086531538*^9}, 3.543784214281*^9, 
   3.5437862255172033`*^9, 3.5437873278854933`*^9, 3.543787411231011*^9, 
   3.543787574213234*^9, 3.543787734317368*^9, 3.543787772674624*^9, 
   3.543790579727277*^9, 3.543790611474038*^9, 3.5438313017421427`*^9, 
   3.543838150861176*^9, 3.543838349401717*^9, 3.543838827409943*^9, 
   3.543838903570077*^9, 3.543843350982695*^9, 3.5439186966308413`*^9, 
   3.543944033592236*^9, 3.5439606968181677`*^9, 3.544014797337749*^9, 
   3.544364787074748*^9, 3.544710288680009*^9, 3.544713491905736*^9, 
   3.544727691607683*^9}],

Cell[BoxData[
 RowBox[{"initialConditionsList", "=", 
  RowBox[{"{", 
   RowBox[{
   "v0", ",", "mNa0", ",", "hNa0", ",", "mNaP0", ",", "hNaP0", ",", "n0", ",",
     "mT0", ",", "hT0", ",", "mP0", ",", "mN0", ",", "hN0", ",", "zSK0", ",", 
    "mA0", ",", "hA0", ",", "mH0", ",", "ca20"}], "}"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "list", " ", "is", " ", "the", " ", "order", " ", "provided", 
    " ", "in", " ", "the", " ", "parameters"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{
  3.543709930991701*^9, {3.543710077270919*^9, 3.543710086531664*^9}, {
   3.544802820490634*^9, 3.544802834277278*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "v0", ",", "mNa0", ",", "hNa0", ",", "mNaP0", ",", "hNaP0", ",", "n0", ",", 
   "mT0", ",", "hT0", ",", "mP0", ",", "mN0", ",", "hN0", ",", "zSK0", ",", 
   "mA0", ",", "hA0", ",", "mH0", ",", "ca20"}], "}"}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{
  3.543709933297289*^9, {3.543710077271058*^9, 3.543710086531784*^9}, 
   3.543784214312764*^9, 3.543786225549753*^9, 3.543787327933083*^9, 
   3.5437874112926607`*^9, 3.5437875742624283`*^9, 3.543787734382908*^9, 
   3.5437877727172413`*^9, 3.543790579776711*^9, 3.543790611510695*^9, 
   3.5438313017907553`*^9, 3.543838150906756*^9, 3.543838349462577*^9, 
   3.543838827451092*^9, 3.5438389036455193`*^9, 3.54384335102822*^9, 
   3.543918696673129*^9, 3.543944033672803*^9, 3.543960696862974*^9, 
   3.5440147973858633`*^9, 3.5443647871319942`*^9, 3.544710288734008*^9, 
   3.544713491941764*^9, 3.544727691672957*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
  "Thread", " ", "initial", " ", "condition", " ", "names", " ", "over", " ", 
   "the", " ", "new", " ", "found", " ", "list", " ", "of", " ", "values"}], 
  " ", "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.543709973892723*^9, 3.543709996619646*^9}, {
  3.543710077271195*^9, 3.5437100865319*^9}, {3.5437842545926332`*^9, 
  3.543784255589837*^9}}],

Cell[BoxData[
 RowBox[{"parametersForInitial", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{"Rule", "[", 
    RowBox[{"initialConditionsList", ",", 
     RowBox[{"initialValues", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "values", " ", "found", " ", "at", " ", "t"}], "=", 
    RowBox[{
    "6000", " ", "ms", " ", "were", " ", "assigned", " ", "to", " ", "the", 
     " ", "names", " ", "of", " ", "the", " ", "parameters"}]}], " ", 
   "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.543709944158185*^9, 3.543709959735478*^9}, {
  3.5437100038375807`*^9, 3.543710023623062*^9}, {3.543710077271325*^9, 
  3.543710086532014*^9}, {3.544802836012745*^9, 3.5448028852522297`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"v0", "\[Rule]", 
    RowBox[{"-", "71.63003254526362`"}]}], ",", 
   RowBox[{"mNa0", "\[Rule]", "0.014894326717078644`"}], ",", 
   RowBox[{"hNa0", "\[Rule]", "0.9807887639851169`"}], ",", 
   RowBox[{"mNaP0", "\[Rule]", "0.002515074108266481`"}], ",", 
   RowBox[{"hNaP0", "\[Rule]", "0.7901792967899248`"}], ",", 
   RowBox[{"n0", "\[Rule]", "0.15906501906411205`"}], ",", 
   RowBox[{"mT0", "\[Rule]", "0.0011978762242570837`"}], ",", 
   RowBox[{"hT0", "\[Rule]", "0.5544275000473116`"}], ",", 
   RowBox[{"mP0", "\[Rule]", "1.2345047571399302`*^-8"}], ",", 
   RowBox[{"mN0", "\[Rule]", "0.0009689397098428325`"}], ",", 
   RowBox[{"hN0", "\[Rule]", "0.6325900160848177`"}], ",", 
   RowBox[{"zSK0", "\[Rule]", "0.0020339820708956055`"}], ",", 
   RowBox[{"mA0", "\[Rule]", "0.05790092771965761`"}], ",", 
   RowBox[{"hA0", "\[Rule]", "0.31844956741657243`"}], ",", 
   RowBox[{"mH0", "\[Rule]", "0.1763168475925179`"}], ",", 
   RowBox[{"ca20", "\[Rule]", "0.00013543687929309795`"}]}], "}"}]], "Output",\

 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{
  3.543709960197525*^9, {3.543710009597087*^9, 3.54371002407469*^9}, {
   3.5437100772714653`*^9, 3.543710086532133*^9}, 3.543784214795741*^9, 
   3.543786225696864*^9, 3.54378732801401*^9, 3.543787411360092*^9, 
   3.5437875743273783`*^9, 3.5437877344449997`*^9, 3.543787772783531*^9, 
   3.543790579844173*^9, 3.54379061159217*^9, 3.5438313018496723`*^9, 
   3.543838150967091*^9, 3.543838349548646*^9, 3.543838827830057*^9, 
   3.543838903745186*^9, 3.5438433510946617`*^9, 3.5439186968748198`*^9, 
   3.5439440338069763`*^9, 3.543960696943782*^9, 3.5440147974544897`*^9, 
   3.5443647871884604`*^9, 3.544710288804335*^9, 3.5447134920225267`*^9, 
   3.544727691910667*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(* Graphing Figure 1: Action Potential (1 nA for 1 ms) with new parameters *)\
\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.5437101007847567`*^9, 3.543710127445245*^9}, 
   3.543710332184877*^9, {3.5438510552312183`*^9, 3.543851067100671*^9}},
 FontSize->16,
 Background->RGBColor[1, 0.9, 0.8]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "The", " ", "code", " ", "was", " ", "rerun", " ", "with", " ", "the", " ", 
   "new", " ", "initial", " ", "conditions", " ", "in", " ", "this", " ", 
   RowBox[{"notebook", "."}]}], "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.544802962523897*^9, 3.544802997214643*^9}, 
   3.544803094389044*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"parametersNew", "=", "\[IndentingNewLine]", 
    RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gNa", "\[Rule]", "0.7"}], 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gNaP", "\[Rule]", "0.05"}], 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gK", "\[Rule]", "1.3"}], " ", 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gleak", "\[Rule]", "0.005"}], 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gT", "\[Rule]", "0.1"}], 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gP", "\[Rule]", "0.05"}], 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gN", "\[Rule]", "0.05"}], 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gSK", "\[Rule]", "0.3"}], 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gA", "\[Rule]", "1.0"}], 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"gH", "\[Rule]", "0.005"}], 
      RowBox[{"(*", "uS", "*)"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"eNa", "\[Rule]", "60"}], 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"eK", "\[Rule]", 
       RowBox[{"-", "80"}]}], 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"eleak", "\[Rule]", 
       RowBox[{"-", "50"}]}], 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"eCa", "\[Rule]", "40"}], 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"eH", "\[Rule]", 
       RowBox[{"-", "38.8"}]}], 
      RowBox[{"(*", "mV", "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"k1", "\[Rule]", 
       RowBox[{"-", "0.0005"}]}], 
      RowBox[{"(*", 
       RowBox[{"M", "/", "nC"}], "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"k2", "\[Rule]", "0.04"}], 
      RowBox[{"(*", 
       RowBox[{"ms", "^", 
        RowBox[{"-", "1"}]}], "*)"}], ",", "\[IndentingNewLine]", 
      RowBox[{"cm", "\[Rule]", "0.040"}], 
      RowBox[{"(*", "nF", "*)"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"tauM", "\[Rule]", "0.1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"taumNaP", "\[Rule]", "0.1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"tauhNaP", "\[Rule]", "150"}], ",", "\[IndentingNewLine]", 
      RowBox[{"taumN", "\[Rule]", "5"}], ",", "\[IndentingNewLine]", 
      RowBox[{"tauhN", "\[Rule]", "25"}], ",", "\[IndentingNewLine]", 
      RowBox[{"taumP", "\[Rule]", "10"}], ",", "\[IndentingNewLine]", 
      RowBox[{"tauzSK", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"tauhA", "\[Rule]", "20"}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"NEW", " ", "initial", " ", "conditions"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"v0", "\[Rule]", 
       RowBox[{"-", "71.6300325523997`"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"mNa0", "\[Rule]", "0.01489432670475539`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"hNa0", "\[Rule]", "0.9807887640044761`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"mNaP0", "\[Rule]", "0.0025150741038981665`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"hNaP0", "\[Rule]", "0.7901792975488681`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"n0", "\[Rule]", "0.15906501902577883`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"mT0", "\[Rule]", "0.001197876222516885`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"hT0", "\[Rule]", "0.5544275003113153`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"mP0", "\[Rule]", "1.2345047540751453`*^-8"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"mN0", "\[Rule]", "0.0009689397086679454`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"hN0", "\[Rule]", "0.632590016702865`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"zSK0", "\[Rule]", "0.002033982067806342`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"mA0", "\[Rule]", "0.057900927695149165`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"hA0", "\[Rule]", "0.31844956757022436`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"mH0", "\[Rule]", "0.17631684662750693`"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ca20", "\[Rule]", "0.0001354368791904773`"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", "functions", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"pulse", "[", 
     RowBox[{"t_", ",", "t0_", ",", "w_", ",", "p_", ",", "D_", ",", "A_"}], 
     "]"}], ":=", " ", 
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"UnitStep", "[", 
          RowBox[{"t", "-", "i"}], "]"}], " ", "-", " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{"t", "-", 
           RowBox[{"(", 
            RowBox[{"i", "+", "w"}], ")"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "t0", ",", 
          RowBox[{"t0", "+", "D"}], ",", "p"}], "}"}]}], "]"}], ")"}]}]}], 
   ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"pulse", " ", "function", " ", "for", " ", "injection"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Inj5", "[", "t_", "]"}], ":=", " ", 
    RowBox[{"pulse", "[", 
     RowBox[{"t", ",", "5", ",", "1", ",", "2", ",", "1", ",", "1"}], "]"}]}],
    ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Single", "-", 
    RowBox[{"pulse", " ", "Injection", " ", 
     RowBox[{"function", ".", " ", "5"}], " ", "second", " ", "delay"}]}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"InjHeld33", "[", "t_", "]"}], ":=", " ", 
    RowBox[{"pulse", "[", 
     RowBox[{"t", ",", "10", ",", "1", ",", "1", ",", "2500", ",", "0.33"}], 
     "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Held", " ", "current", " ", "for", " ", "2500", " ", "ms", " ", "and", 
    " ", "an", " ", "amplitude", " ", "of", " ", "0.33", " ", "nA"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"InjHeld22", "[", "t_", "]"}], ":=", 
    RowBox[{"pulse", "[", 
     RowBox[{"t", ",", "2", ",", "1", ",", "1", ",", "2500", ",", "0.22"}], 
     "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "Held", " ", "current", " ", "for", " ", "2500", " ", "ms", " ", "and", 
    " ", "an", " ", "amplitude", " ", "of", " ", "0.22", " ", "nA"}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"steady", "-", 
    RowBox[{
    "state", " ", "voltage", " ", "dependent", " ", "activation", " ", "and", 
     " ", "inactivation", " ", "functions", " ", "with", " ", "time", " ", 
     "constants"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"minfin", "[", "v_", "]"}], ":=", 
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"E", "^", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"v", "+", "36"}], ")"}], "/", "8.5"}], ")"}]}]}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"v", "+", "44.1"}], ")"}], "/", "7"}], ")"}]}]}], 
      ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
    RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iNa"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tauH", "[", "v_", "]"}], ":=", 
    RowBox[{
     RowBox[{"3.5", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "35"}], ")"}], "/", "4"}], ")"}]}], "+", 
        RowBox[{"E", "^", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "35"}], ")"}], "/", "25"}], ")"}]}]}]}], 
       ")"}]}], "+", "1"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"function", " ", "for", " ", "time"}], "-", 
    RowBox[{"constant", " ", "of", " ", "iNa"}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"mNaPinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"v", "+", "47.1"}], ")"}]}], "/", "4.1"}], ")"}]}]}], 
      ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
    RowBox[{"dependent", " ", "activation", " ", "of", " ", "iNaP"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hNaPinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"v", "+", "65"}], ")"}], "/", "5"}], ")"}]}]}], ")"}]}]}], 
   ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
    RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iNaP"}]}], " ",
    "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ninfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "30"}], ")"}], "/", "25"}], ")"}]}]}]}], 
      ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"function", " ", "for", " ", "voltage"}], "-", 
    RowBox[{"dependent", " ", 
     RowBox[{"(", "in", ")"}], "activation", " ", "of", " ", "iK"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tauN", "[", "v_", "]"}], ":=", 
    RowBox[{
     RowBox[{"2.5", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "30"}], ")"}], "/", "40"}], ")"}]}], "+", 
        RowBox[{"E", "^", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"v", "+", "30"}], ")"}], "/", "50"}], ")"}]}]}]}], 
       ")"}]}], "+", "0.01"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "function", " ", "for", " ", "time", " ", "constant", " ", "of", " ", 
    "ik"}], " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"mTinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "38"}], ")"}], "/", "5"}], ")"}]}]}]}], 
      ")"}]}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"activation", " ", "function", " ", "iT"}], " ", "*)"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"taumt", "[", "v_", "]"}], ":=", 
    RowBox[{
     RowBox[{"5", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "28"}], ")"}], "/", "25"}], ")"}]}], "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"v", "+", "28"}], ")"}]}], "/", "70"}], ")"}]}]}], 
       ")"}]}], "+", "2"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"activation", " ", "time", " ", "constant", " ", "iT"}], "*)"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hTinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"v", "+", "70.1"}], ")"}], "/", "7"}], ")"}]}]}], 
      ")"}]}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"inactivation", " ", "function", " ", "iT"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tauht", "[", "v_", "]"}], ":=", 
    RowBox[{
     RowBox[{"20", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "70"}], ")"}], "/", "65"}], ")"}]}], "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"v", "+", "70"}], ")"}]}], "/", "65"}], ")"}]}]}], 
       ")"}]}], "+", "1"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"inactivation", " ", "time", " ", "constant", " ", "iT"}], " ", 
   "*)"}], " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"mNinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "30"}], ")"}], "/", "6"}], ")"}]}]}]}], 
      ")"}]}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"activation", " ", "function", " ", "iN"}], " ", "*)"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hNinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"v", "+", "70"}], ")"}], "/", "3"}], ")"}]}]}], ")"}]}]}], 
   ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"inactivation", " ", "function", " ", "iN"}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"mPinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "17"}], ")"}], "/", "3"}], ")"}]}]}]}], 
      ")"}]}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"inactivation", " ", "function", " ", "iP"}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"zSKinfin", "[", "ca2_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"0.003", "/", "ca2"}], ")"}], "^", "2"}]}], ")"}]}]}], ";"}],
   " ", 
  RowBox[{"(*", " ", "iSK", " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"mAinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "27"}], ")"}], "/", "16"}], ")"}]}]}]}], 
      ")"}]}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"activation", " ", "function", " ", "Ia"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"taumA", "[", "v_", "]"}], ":=", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "40"}], ")"}], "/", "5"}], ")"}]}], "+", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"v", "+", "74"}], ")"}]}], "/", "7.5"}], ")"}]}]}], 
       ")"}]}], "+", "0.37"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"activation", " ", "time", " ", "constant", " ", "Ia"}], " ", 
   "*)"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hAinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"v", "+", "80"}], ")"}], "/", "11"}], ")"}]}]}], ")"}]}]}],
    ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"inactivation", " ", "function", " ", "constant", " ", "Ia"}], " ",
    "*)"}], " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"taumH", "[", "v_", "]"}], ":=", 
   RowBox[{
    RowBox[{"475", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"v", "+", "70"}], ")"}], "/", "11"}], ")"}]}], "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"v", "+", "70"}], ")"}]}], "/", "11"}], ")"}]}]}], 
      ")"}]}], "+", "50"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"mHinfin", "[", "v_", "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"v", "+", "79.8"}], ")"}], "/", "5.3"}], ")"}]}]}], 
      ")"}]}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"I", " ", "ionic", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ileak", "[", "v_", "]"}], ":=", 
    RowBox[{
     RowBox[{"gleak", "*", 
      RowBox[{"(", 
       RowBox[{"v", "-", "eleak"}], ")"}]}], "/.", "parametersNew"}]}], ";"}],
   " ", 
  RowBox[{"(*", 
   RowBox[{"function", " ", "for", " ", "iLeak", " ", "current"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"iNaP", "[", 
     RowBox[{"v_", ",", "mNaP_", ",", "hNaP_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"gNaP", "*", "mNaP", "*", "hNaP", "*", 
      RowBox[{"(", 
       RowBox[{"v", "-", "eNa"}], ")"}]}], "/.", "parametersNew"}]}], ";"}], 
  " ", 
  RowBox[{"(*", " ", 
   RowBox[{"function", " ", "for", " ", "INaP"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"iNa", "[", 
     RowBox[{"v_", ",", "mNa_", ",", "hNa_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"gNa", "*", 
      RowBox[{"(", 
       RowBox[{"mNa", "^", "3"}], ")"}], "*", "hNa", "*", 
      RowBox[{"(", 
       RowBox[{"v", "-", "eNa"}], ")"}]}], "/.", "parametersNew"}]}], ";"}], 
  " ", 
  RowBox[{"(*", " ", 
   RowBox[{"function", " ", "for", " ", "INa"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"iK", "[", 
     RowBox[{"v_", ",", "n_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"gK", "*", 
      RowBox[{"(", 
       RowBox[{"n", "^", "4"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{"v", "-", "eK"}], ")"}]}], "/.", "parametersNew"}]}], ";"}], 
  " ", 
  RowBox[{"(*", " ", 
   RowBox[{"function", " ", "for", " ", "Ik"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"iT", "[", 
    RowBox[{"v_", ",", "mT_", ",", "hT_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"gT", "*", "mT", "*", "hT", "*", 
     RowBox[{"(", 
      RowBox[{"v", "-", "eCa"}], ")"}]}], "/.", "parametersNew"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"iN", "[", 
    RowBox[{"v_", ",", "mN_", ",", "hN_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"gN", "*", "mN", "*", "hN", "*", 
     RowBox[{"(", 
      RowBox[{"v", "-", "eCa"}], ")"}]}], "/.", "parametersNew"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"iP", "[", 
    RowBox[{"v_", ",", "mP_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"gP", "*", "mP", "*", 
     RowBox[{"(", 
      RowBox[{"v", "-", "eCa"}], ")"}]}], "/.", "parametersNew"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"iSK", "[", 
    RowBox[{"v_", ",", "zSK_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"gSK", "*", 
     RowBox[{"(", 
      RowBox[{"zSK", "^", "2"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"v", "-", "eK"}], ")"}]}], "/.", "parametersNew"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"iA", "[", 
    RowBox[{"v_", ",", "mA_", ",", "hA_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"gA", "*", "mA", "*", "hA", "*", 
     RowBox[{"(", 
      RowBox[{"v", "-", "eK"}], ")"}]}], "/.", "parametersNew"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"iH", "[", 
     RowBox[{"v_", ",", "mH_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"gH", "*", "mH", "*", 
      RowBox[{"(", 
       RowBox[{"v", "-", "eH"}], ")"}]}], "/.", "parametersNew"}]}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.543710154137315*^9, 3.5437102662623787`*^9}, 
   3.5437103321850357`*^9, {3.54371167082028*^9, 3.543711679425251*^9}, {
   3.54371172600565*^9, 3.543711726217085*^9}, {3.543711768711729*^9, 
   3.5437118052376633`*^9}, {3.543785878418845*^9, 3.543785888358*^9}, {
   3.543790446787869*^9, 3.543790493460631*^9}, {3.544269976653941*^9, 
   3.544269976826151*^9}, {3.544270059022861*^9, 3.544270059193983*^9}, {
   3.5442793297414007`*^9, 3.544279329891633*^9}, {3.544279404785543*^9, 
   3.544279407976342*^9}, {3.544802923894706*^9, 3.544802982839616*^9}}],

Cell[BoxData[
 RowBox[{"solutionVoltageNew", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"mNa", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"minfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mNa", "[", "t", "]"}]}], ")"}], "/", "tauM"}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "INa"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mNa", "[", "0", "]"}], "\[Equal]", "mNa0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hNa", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hNa", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"tauH", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inaction", " ", "of", " ", "INa"}]}], " ",
         "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hNa", "[", "0", "]"}], "\[Equal]", "hNa0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mNaP", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mNaPinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mNaP", "[", "t", "]"}]}], ")"}], "/", "taumNaP"}]}], ",", 
       
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "INaP"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mNaP", "[", "0", "]"}], "\[Equal]", "mNaP0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hNaP", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hNaPinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hNaP", "[", "t", "]"}]}], ")"}], "/", "tauhNaP"}]}], ",", 
       " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "INaP"}]}],
         " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hNaP", "[", "0", "]"}], "\[Equal]", "hNaP0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"n", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ninfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"n", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"tauN", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", 
          RowBox[{"(", "in", ")"}], "activation", " ", "of", " ", "Ik"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"n", "[", "0", "]"}], "\[Equal]", "n0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mT", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mTinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mT", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"taumt", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "iT"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mT", "[", "0", "]"}], "\[Equal]", "mT0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hT", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hTinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hT", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"tauht", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iT"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hT", "[", "0", "]"}], "\[Equal]", "hT0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mN", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mNinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mN", "[", "t", "]"}]}], ")"}], "/", "taumN"}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "iN"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mN", "[", "0", "]"}], "\[Equal]", "mN0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hN", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hNinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hN", "[", "t", "]"}]}], ")"}], "/", "tauhN"}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iN"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hN", "[", "0", "]"}], "\[Equal]", "hN0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mP", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mPinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mP", "[", "t", "]"}]}], ")"}], "/", "taumP"}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "iP"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mP", "[", "0", "]"}], "\[Equal]", "mP0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"zSK", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zSKinfin", "[", 
            RowBox[{"ca2", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"zSK", "[", "t", "]"}]}], ")"}], "/", "tauzSK"}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "calcium"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "iSK"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"zSK", "[", "0", "]"}], "\[Equal]", "zSK0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ca2", "'"}], "[", "t", "]"}], "\[Equal]", " ", 
        RowBox[{
         RowBox[{"k1", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"gT", "*", 
              RowBox[{"mT", "[", "t", "]"}], "*", 
              RowBox[{"hT", "[", "t", "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], "-", "eCa"}], ")"}]}], ")"}], 
            "+", 
            RowBox[{"(", 
             RowBox[{"gN", "*", 
              RowBox[{"mN", "[", "t", "]"}], "*", 
              RowBox[{"hN", "[", "t", "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], "-", "eCa"}], ")"}]}], ")"}], 
            "+", 
            RowBox[{"(", 
             RowBox[{"gP", "*", 
              RowBox[{"mP", "[", "t", "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"v", "[", "t", "]"}], "-", "eCa"}], ")"}]}], ")"}]}], 
           ")"}]}], "-", 
         RowBox[{"k2", "*", 
          RowBox[{"ca2", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ca2", "[", "0", "]"}], "\[Equal]", "ca20"}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
        "solving", " ", "for", " ", "calcium", " ", "concentration", " ", 
         "within", " ", "the", " ", 
         RowBox[{"cell", ".", " ", "Includes"}], " ", "all", " ", "three", 
         " ", "calcium", " ", 
         RowBox[{"channels", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mA", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mAinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mA", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"taumA", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "activation", " ", "of", " ", "iA"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mA", "[", "0", "]"}], "\[Equal]", "mA0"}], ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"hA", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"hAinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"hA", "[", "t", "]"}]}], ")"}], "/", "tauhA"}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iA"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hA", "[", "0", "]"}], "\[Equal]", "hA0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"mH", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mHinfin", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], "-", 
           RowBox[{"mH", "[", "t", "]"}]}], ")"}], "/", 
         RowBox[{"taumH", "[", 
          RowBox[{"v", "[", "t", "]"}], "]"}]}]}], ",", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"solving", " ", "for", " ", "voltage"}], "-", 
         RowBox[{"dependent", " ", "inactivation", " ", "of", " ", "iA"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mH", "[", "0", "]"}], "\[Equal]", "mH0"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"Hodgkin", "-", 
           RowBox[{"Huxley", " ", 
            RowBox[{"formula", ".", " ", "Add"}], " ", "all", " ", "of", " ", 
            "the", " ", "voltages", " ", 
            RowBox[{"(", 
             RowBox[{"including", " ", "iLeak"}], ")"}]}]}], ",", " ", 
          RowBox[{"plus", " ", "the", " ", "injected", " ", "current"}]}], 
         " ", "*)"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", "cm"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"iNa", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"mNa", "[", "t", "]"}], ",", 
                 RowBox[{"hNa", "[", "t", "]"}]}], "]"}], "+", 
               RowBox[{"iNaP", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"mNaP", "[", "t", "]"}], ",", 
                 RowBox[{"hNaP", "[", "t", "]"}]}], "]"}], "+", 
               RowBox[{"iA", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"mA", "[", "t", "]"}], ",", 
                 RowBox[{"hA", "[", "t", "]"}]}], "]"}], "+", 
               RowBox[{"iH", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"mH", "[", "t", "]"}]}], "]"}], "+", "    ", 
               RowBox[{"iSK", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"zSK", "[", "t", "]"}]}], "]"}], " ", "+", " ", 
               RowBox[{"iK", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"n", "[", "t", "]"}]}], "]"}], "+", 
               RowBox[{"iT", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"mT", "[", "t", "]"}], ",", 
                 RowBox[{"hT", "[", "t", "]"}]}], "]"}], "+", 
               RowBox[{"iP", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"mP", "[", "t", "]"}]}], "]"}], "+", 
               RowBox[{"iN", "[", 
                RowBox[{
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"mN", "[", "t", "]"}], ",", 
                 RowBox[{"hN", "[", "t", "]"}]}], "]"}], "+", 
               RowBox[{"ileak", "[", 
                RowBox[{"v", "[", "t", "]"}], "]"}]}], ")"}], ")"}]}], "   ", 
           "+", "  ", 
           RowBox[{"Inj5", "[", "t", "]"}]}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"v", "[", "0", "]"}], "\[Equal]", "v0"}]}], 
      "\[IndentingNewLine]", "}"}], " ", "/.", "parametersNew"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mNaP", "[", "t", "]"}], ",", 
      RowBox[{"hNaP", "[", "t", "]"}], ",", " ", 
      RowBox[{"mNa", "[", "t", "]"}], ",", 
      RowBox[{"hNa", "[", "t", "]"}], ",", " ", 
      RowBox[{"n", "[", "t", "]"}], ",", 
      RowBox[{"mT", "[", "t", "]"}], ",", 
      RowBox[{"hT", "[", "t", "]"}], ",", 
      RowBox[{"mN", "[", "t", "]"}], ",", 
      RowBox[{"hN", "[", "t", "]"}], ",", 
      RowBox[{"mP", "[", "t", "]"}], ",", 
      RowBox[{"mA", "[", "t", "]"}], ",", 
      RowBox[{"hA", "[", "t", "]"}], ",", "  ", 
      RowBox[{"zSK", "[", "t", "]"}], ",", " ", 
      RowBox[{"ca2", "[", "t", "]"}], ",", "  ", 
      RowBox[{"mH", "[", "t", "]"}], ",", 
      RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"MaxSteps", "\[Rule]", "100000"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.543790537456196*^9, 3.5437905623307877`*^9}, 
   3.543791093033744*^9, {3.544269988180179*^9, 3.544269991201004*^9}, {
   3.5442700486636047`*^9, 3.544270050702263*^9}, {3.544279335325592*^9, 
   3.544279338291078*^9}, {3.544279395087697*^9, 3.54427939822466*^9}, 
   3.5448029087638807`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"mNaP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hNaP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mNa", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hNa", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mT", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hT", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mN", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hN", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mP", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mA", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"hA", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"zSK", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"ca2", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"mH", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "10000.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}],
         "]"}],
       False,
       Editable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.5437905647256308`*^9, 3.543790579958234*^9}, 
   3.5437906117137537`*^9, 3.543791093033916*^9, 3.543831301982293*^9, 
   3.543838151079875*^9, 3.543838349685994*^9, 3.54383882800347*^9, 
   3.5438389038846493`*^9, 3.5438433512177877`*^9, 3.543918697068331*^9, 
   3.543944033929784*^9, 3.543960697071073*^9, 3.544014797621325*^9, {
   3.544269993729096*^9, 3.54427001234052*^9}, 3.544270066933303*^9, 
   3.5442793492005053`*^9, 3.544279412865109*^9, 3.544364787349766*^9, 
   3.544710289041086*^9, 3.544713492220037*^9, 3.544727692118362*^9}],

Cell[BoxData[
 RowBox[{"graphNewWithStim", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"v", "[", "t", "]"}], "/.", "\[InvisibleSpace]", 
      "solutionVoltageNew"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "1000"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "100"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "80"}], ",", 
         RowBox[{"-", "50"}]}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (ms)\>\"", ",", " ", "\"\<Voltage (mV)\>\""}], 
      "}"}]}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Plot", " ", "of", " ", "action", " ", "potential", " ", "using", " ", 
    "the", " ", "new", " ", "parameters", " ", "with", " ", "a", " ", 
    RowBox[{"stimulation", ".", " ", "Notice"}], " ", "the", " ", "5", " ", 
    "second", " ", "delay"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.543710281876515*^9, 3.5437102906199303`*^9}, 
   3.54371033218535*^9, {3.54427002161722*^9, 3.544270021815106*^9}, {
   3.544270071446513*^9, 3.544270072333962*^9}, {3.544279352385604*^9, 
   3.544279352591157*^9}, {3.544279418742799*^9, 3.544279419174213*^9}, {
   3.544803046745163*^9, 3.544803083392454*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[Large], 
    LineBox[{{0.000020408163265306123`, -71.6300325523997}, {
     2.453600507334157, -71.63003255227466}, {
     4.907180606505049, -71.63003255240214}, {
     5.213878118901411, -66.60785254252966}, {
     5.520575631297772, -60.202443778381785`}, {
     5.827273143694134, -53.4512532505229}, {5.93077174428815, -50.}}], 
    LineBox[CompressedData["
1:eJwd13k4VO8XAHBrtqJFiGxZvkiUfXfs+zJ3LNmXwSAlUYRQWVtMSUooLSSK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Voltage (mV)\"", TraditionalForm]},
  AxesOrigin->{0, -80.},
  PlotRange->{{0, 100}, {-80, -50}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{
  3.543710291737576*^9, 3.543710332185491*^9, 3.5437117420780478`*^9, 
   3.5437118090770493`*^9, 3.543784215025662*^9, 3.543786225838212*^9, 
   3.54378732815047*^9, 3.543787411509151*^9, 3.5437875744695263`*^9, 
   3.543787734601323*^9, 3.543787772937538*^9, {3.543790567288472*^9, 
   3.5437905800092297`*^9}, 3.5437906117600327`*^9, 3.5438313020990973`*^9, 
   3.543838151122013*^9, 3.5438383497959223`*^9, 3.5438388281572313`*^9, 
   3.543838903989986*^9, 3.5438433512719927`*^9, 3.543918697129457*^9, 
   3.543944034061808*^9, 3.543960697113348*^9, 3.544014797668949*^9, {
   3.5442700132935257`*^9, 3.544270022126856*^9}, {3.544270068584703*^9, 
   3.544270072571609*^9}, 3.5442793529733667`*^9, {3.544279415984919*^9, 
   3.544279419455483*^9}, 3.544364787410602*^9, 3.544710289087997*^9, 
   3.544713492260075*^9, 3.5447276921843*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Action", " ", "potential", " ", "appears", " ", "like", " ", "the", " ", 
   "Purvis", " ", "and", " ", "Butera", " ", 
   RowBox[{"model", "'"}], "s", " ", "Figure", " ", "1"}], " ", 
  "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.5448030043043623`*^9, 3.544803040374463*^9}, 
   3.544803094389246*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["(* Graphing Figure 2: Ionic Currents *)", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710343064886*^9, 3.543710377051296*^9}, 
   3.543711322273609*^9},
 FontSize->16,
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
(* This code was written by me. Elena and I collaborated on the logic for the \
sodium currents. I sent the rest of the code afterwards. Use parametersNew \
and solutionVoltageNew and plot the current equations *)\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710394774919*^9, 3.5437104387150173`*^9}, 
   3.543711322273765*^9, {3.544803188728107*^9, 3.544803219082282*^9}}],

Cell["(*Graphing 2A, Sodium Currents *)", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710502811555*^9, 3.54371052796943*^9}, 
   3.543711322273884*^9},
 FontSize->14,
 Background->RGBColor[1, 0.9, 1]],

Cell[BoxData[
 RowBox[{"graphNa", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"iNa", "[", 
       RowBox[{
        RowBox[{"v", "[", "t", "]"}], ",", 
        RowBox[{"mNa", "[", "t", "]"}], ",", 
        RowBox[{"hNa", "[", "t", "]"}]}], "]"}], "/.", "solutionVoltageNew"}],
      "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10000"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25"}], ",", "0"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"PlotPoints", "\[Rule]", "1000"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (mS)\>\"", ",", " ", "\"\<Current (nA)\>\""}], 
      "}"}]}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "iNa", " ", "from", " ", "ionic", " ", "current", " ", "function"}], " ", 
   "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{
  3.543710391481621*^9, {3.543710443449275*^9, 3.5437104442220182`*^9}, {
   3.543711045891409*^9, 3.543711048866952*^9}, 3.543711322274027*^9, {
   3.544803111841332*^9, 3.544803139838481*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJws23c4lV8cAHB7lz1DSFll3SuU+IbMkp1NNiVlZZbsJBGZZe+9V3KMjBKJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 15}, {-25, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.543710445046576*^9, 3.543711064983025*^9, 
  3.5437113222741833`*^9, 3.543711754132146*^9, 3.543711855185185*^9, 
  3.543784215118438*^9, 3.543786226890436*^9, 3.54378732821837*^9, 
  3.5437874115727158`*^9, 3.5437875745337687`*^9, 3.5437877346693*^9, 
  3.54378777301119*^9, 3.543790580071808*^9, 3.5437906118296843`*^9, 
  3.543831302167775*^9, 3.543838151189027*^9, 3.543838349859173*^9, 
  3.543838828419817*^9, 3.5438389040530987`*^9, 3.5438433514616947`*^9, 
  3.5439186972017508`*^9, 3.5439440341550903`*^9, 3.543960697188711*^9, 
  3.544014797746686*^9, 3.544364787503944*^9, 3.544710289175413*^9, 
  3.5447134924034777`*^9, 3.544727692459036*^9}],

Cell[BoxData[
 RowBox[{"graphNaP", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"iNaP", "[", 
       RowBox[{
        RowBox[{"v", "[", "t", "]"}], ",", 
        RowBox[{"mNaP", "[", "t", "]"}], ",", 
        RowBox[{"hNaP", "[", "t", "]"}]}], "]"}], "/.", 
      "solutionVoltageNew"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Red", ",", 
       RowBox[{"Dashing", "[", 
        RowBox[{"{", 
         RowBox[{"0.01", ",", "0.01"}], "}"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25"}], ",", "0"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (mS)\>\"", ",", " ", "\"\<Current (nA)\>\""}], 
      "}"}]}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{"iNaP", " ", "from", " ", "ionic", " ", "function"}], 
   "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.5437104689828577`*^9, 3.543710478830591*^9}, {
   3.543711051955255*^9, 3.5437110590346603`*^9}, 3.543711322274325*^9, {
   3.5448031180636*^9, 3.544803129967304*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Dashing[{0.01, 0.01}], 
    LineBox[CompressedData["
1:eJwt13k4Vd/3OHBkqFDKTGaZM0/hsswRkvEmopR7DSHzPA+5SUSSFIm4olQo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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 15}, {-25, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.543710479601337*^9, 3.5437110670878696`*^9, 
  3.543711322274467*^9, 3.5437842151856127`*^9, 3.5437862273611*^9, 
  3.543787328268231*^9, 3.543787411627338*^9, 3.543787574599135*^9, 
  3.543787734751793*^9, 3.543787773072712*^9, 3.543790580126666*^9, 
  3.5437906118946753`*^9, 3.543831302228397*^9, 3.543838151238697*^9, 
  3.543838349943688*^9, 3.54383882858918*^9, 3.5438389041144323`*^9, 
  3.543843351645906*^9, 3.543918697540534*^9, 3.543944034229789*^9, 
  3.54396069725*^9, 3.5440147978890867`*^9, 3.544364787566676*^9, 
  3.544710289921208*^9, 3.544713492508401*^9, 3.5447276926045856`*^9}],

Cell[BoxData[
 RowBox[{"figure2A", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"graphNa", ",", "graphNaP"}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Composite", " ", "like", " ", "Figure", " ", "2", "A"}], " ", 
   "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710489649288*^9, 3.543710492282435*^9}, 
   3.5437113222746067`*^9, {3.544803144602631*^9, 3.5448031506739693`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJws23c4lV8cAHB7lz1DSFll3SuU+IbMkp1NNiVlZZbsJBGZZe+9V3KMjBKJ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      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], Dashing[{0.01, 0.01}], 
     LineBox[CompressedData["
1:eJwt13k4Vd/3OHBkqFDKTGaZM0/hsswRkvEmopR7DSHzPA+5SUSSFIm4olQo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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (mS)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 15}, {-25, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.543710493051248*^9, 3.543711069679133*^9, 
  3.543711322274746*^9, 3.543784215240711*^9, 3.5437862274160233`*^9, 
  3.543787328341099*^9, 3.543787411705236*^9, 3.543787574671853*^9, 
  3.54378773492393*^9, 3.543787773247164*^9, 3.543790580181945*^9, 
  3.543790611967382*^9, 3.543831302278688*^9, 3.543838151398135*^9, 
  3.543838350003791*^9, 3.543838828950262*^9, 3.543838904185356*^9, 
  3.54384335171212*^9, 3.543918697617978*^9, 3.543944034450326*^9, 
  3.543960697338153*^9, 3.544014798035944*^9, 3.5443647876442432`*^9, 
  3.544710289995623*^9, 3.544713492646573*^9, 3.5447276927438917`*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Blue", ":", "iNa"}], ",", 
   RowBox[{"Red", ":", "iNaP"}]}], " ", "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710889101926*^9, 3.543710911051689*^9}, 
   3.543711322274888*^9}],

Cell["(* Graphing 2B: Calcium Currents *)", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710577600572*^9, 3.543710603789174*^9}, 
   3.543711322275014*^9},
 FontSize->14,
 Background->RGBColor[1, 0.9, 1]],

Cell[BoxData[
 RowBox[{"graphCa", "=", 
  RowBox[{"(*", 
   RowBox[{"iCa", "=", 
    RowBox[{"iN", "+", "iP", "+", "iT"}]}], "*)"}], 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"iN", "[", 
         RowBox[{
          RowBox[{"v", "[", "t", "]"}], ",", 
          RowBox[{"mN", "[", "t", "]"}], ",", 
          RowBox[{"hN", "[", "t", "]"}]}], "]"}], "+", 
        RowBox[{"iP", "[", 
         RowBox[{
          RowBox[{"v", "[", "t", "]"}], ",", 
          RowBox[{"mP", "[", "t", "]"}]}], "]"}], "+", 
        RowBox[{"iT", "[", 
         RowBox[{
          RowBox[{"v", "[", "t", "]"}], ",", 
          RowBox[{"mT", "[", "t", "]"}], ",", 
          RowBox[{"hT", "[", "t", "]"}]}], "]"}]}], ")"}], "/.", 
      "solutionVoltageNew"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "100"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.5"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (ms)\>\"", ",", " ", "\"\<Current (nA)\>\""}], 
      "}"}]}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "iCa", " ", "from", " ", "addition", " ", "of", " ", "three", " ", 
    "calcium", " ", "functions"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710621992478*^9, 3.5437106259624033`*^9}, {
   3.543710656683714*^9, 3.543710682256947*^9}, {3.543711077155281*^9, 
   3.543711079010144*^9}, 3.54371132227514*^9, {3.544803159152239*^9, 
   3.5448031792193947`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwt13k0Ve/XAHBEqVTmKUmokMxJxm3MeElmzckUksiQStx7jcmsVOYKqSRU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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 100}, {-2.5, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.543710627050229*^9, 3.543711119298593*^9, 
  3.543711322275282*^9, 3.5437842153231993`*^9, 3.5437862275530653`*^9, 
  3.543787328436878*^9, 3.543787411928347*^9, 3.543787574787319*^9, 
  3.543787735124156*^9, 3.543787773342928*^9, 3.543790580267365*^9, 
  3.543790612064954*^9, 3.543831302384323*^9, 3.543838151481112*^9, 
  3.543838350127017*^9, 3.543838829088876*^9, 3.543838904290104*^9, 
  3.543843351823517*^9, 3.543918697749876*^9, 3.5439440345721273`*^9, 
  3.543960697479883*^9, 3.544014798132708*^9, 3.544364787804577*^9, 
  3.544710290097015*^9, 3.544713492805449*^9, 3.544727692985725*^9}],

Cell[BoxData[
 RowBox[{"graphN", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"iN", "[", 
       RowBox[{
        RowBox[{"v", "[", "t", "]"}], ",", 
        RowBox[{"mN", "[", "t", "]"}], ",", 
        RowBox[{"hN", "[", "t", "]"}]}], "]"}], "/.", "solutionVoltageNew"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "100"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.5"}], ",", "0"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"Dashing", "[", 
        RowBox[{"{", 
         RowBox[{"0.02", ",", "0.02"}], "}"}], "]"}], ",", "Thick"}], "}"}]}],
     ",", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (ms)\>\"", ",", " ", "\"\<Current (nA)\>\""}], 
      "}"}]}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "iN", " ", "from", " ", "the", " ", "ionic", " ", "current", " ", 
    "function"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710642960999*^9, 3.543710646992598*^9}, {
   3.543711082570195*^9, 3.543711083929798*^9}, 3.543711322275422*^9, {
   3.544803233092362*^9, 3.544803254275549*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Dashing[{0.02, 0.02}], 
    LineBox[CompressedData["
1:eJwt13k8lN/3AHBlSSXJTshalISQrMc+iGSbyT52MbIWskZZkmwhimxZohCK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 100}, {-2.5, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.54371064795404*^9, 3.5437111160787477`*^9, 
  3.5437113222755613`*^9, 3.543784215367299*^9, 3.543786227610983*^9, 
  3.543787328700968*^9, 3.543787411989476*^9, 3.543787574865315*^9, 
  3.5437877351807823`*^9, 3.5437877735090723`*^9, 3.543790580313692*^9, 
  3.543790612224317*^9, 3.543831302447422*^9, 3.543838151538547*^9, 
  3.543838350197249*^9, 3.5438388291813707`*^9, 3.543838904348556*^9, 
  3.543843351900571*^9, 3.543918698079896*^9, 3.5439440346419086`*^9, 
  3.5439606975483828`*^9, 3.544014798189023*^9, 3.544364787863099*^9, 
  3.5447102901536837`*^9, 3.544713492986603*^9, 3.544727693123382*^9}],

Cell[BoxData[
 RowBox[{"graphT", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"iT", "[", 
       RowBox[{
        RowBox[{"v", "[", "t", "]"}], ",", 
        RowBox[{"mT", "[", "t", "]"}], ",", 
        RowBox[{"hT", "[", "t", "]"}]}], "]"}], "/.", "solutionVoltageNew"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "100"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.5"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Green", ",", "Thick", ",", 
       RowBox[{"Dashing", "[", 
        RowBox[{"{", 
         RowBox[{"0.005", ",", "0.005"}], "}"}], "]"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (ms)\>\"", ",", " ", "\"\<Current (nA)\>\""}], 
      "}"}]}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "iT", " ", "from", " ", "the", " ", "ionic", " ", "current", " ", 
    "function"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.5437107029750557`*^9, 3.5437107071181173`*^9}, {
   3.543711087274074*^9, 3.5437110894094753`*^9}, 3.543711322275702*^9, {
   3.544803257267355*^9, 3.544803266794531*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0, 1, 0], Thickness[Large], Dashing[{0.005, 0.005}], 
    LineBox[CompressedData["
1:eJwt13k4VV0XAHBEE6kkU5QoIck8D8t4LyJeRIaMlele15zhokyZhaRIRQqp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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 100}, {-2.5, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.543711109394012*^9, 3.543711322275848*^9, 
  3.5437842154161367`*^9, 3.5437862276609993`*^9, 3.54378732876441*^9, 
  3.5437874121466427`*^9, 3.543787575052147*^9, 3.543787735247991*^9, 
  3.5437877735723677`*^9, 3.543790580391365*^9, 3.543790612276827*^9, 
  3.543831302506131*^9, 3.543838151587213*^9, 3.543838350248179*^9, 
  3.543838829264987*^9, 3.543838904406728*^9, 3.543843351994274*^9, 
  3.543918698243372*^9, 3.543944034706209*^9, 3.5439606977103443`*^9, 
  3.54401479825489*^9, 3.544364787917489*^9, 3.544710290212428*^9, 
  3.544713493128613*^9, 3.5447276932733717`*^9}],

Cell[BoxData[
 RowBox[{"graphP", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"iP", "[", 
       RowBox[{
        RowBox[{"v", "[", "t", "]"}], ",", 
        RowBox[{"mP", "[", "t", "]"}]}], "]"}], "/.", "solutionVoltageNew"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "100"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.5"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Orange", ",", "Thick", ",", 
       RowBox[{"Dashing", "[", 
        RowBox[{"{", 
         RowBox[{"0.03", ",", "0.03"}], "}"}], "]"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (ms)\>\"", ",", " ", "\"\<Current (nA)\>\""}], 
      "}"}]}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
   "iP", " ", "from", " ", "the", " ", "ionic", " ", "current", " ", 
    "function"}], " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.5437107249026937`*^9, 3.5437107283975*^9}, {
   3.543711093656713*^9, 3.543711095321197*^9}, 3.5437113222759867`*^9, {
   3.544803269962913*^9, 3.544803279322465*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0.5, 0], Thickness[Large], Dashing[{0.03, 0.03}], 
    LineBox[CompressedData["
1:eJwt1nc0Fo73B3AKSZLs8dhSRkIIGdfem8eDMkq2ZO+QUEhIqEhWRsoIhTxX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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 100}, {-2.5, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.543710739064546*^9, 3.543711096427009*^9, 
  3.543711322276127*^9, 3.543784215460805*^9, 3.54378622771445*^9, 
  3.543787328823428*^9, 3.5437874122095957`*^9, 3.543787575110462*^9, 
  3.5437877353128977`*^9, 3.543787773637718*^9, 3.5437905804474*^9, 
  3.54379061234516*^9, 3.543831302561295*^9, 3.5438381516614*^9, 
  3.5438383502988243`*^9, 3.5438388293468943`*^9, 3.54383890447924*^9, 
  3.543843352061273*^9, 3.543918698407188*^9, 3.543944034777277*^9, 
  3.543960697785264*^9, 3.544014798319867*^9, 3.5443647879848213`*^9, 
  3.544710290269361*^9, 3.5447134932764673`*^9, 3.544727693435182*^9}],

Cell[BoxData[
 RowBox[{"figure2B", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"graphCa", ",", "graphT", ",", "graphN", ",", "graphP"}], "]"}], 
  " ", 
  RowBox[{"(*", " ", "Composite", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{
  3.543710750059676*^9, 3.543711322276333*^9, {3.544803284742812*^9, 
   3.544803288758041*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwt13k0Ve/XAHBEqVTmKUmokMxJxm3MeElmzckUksiQStx7jcmsVOYKqSRU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      "]]}}, {{}, {}, 
    {RGBColor[0, 1, 0], Thickness[Large], Dashing[{0.005, 0.005}], 
     LineBox[CompressedData["
1:eJwt13k4VV0XAHBEE6kkU5QoIck8D8t4LyJeRIaMlele15zhokyZhaRIRQqp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      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], Dashing[{0.02, 0.02}], 
     LineBox[CompressedData["
1:eJwt13k8lN/3AHBlSSXJTshalISQrMc+iGSbyT52MbIWskZZkmwhimxZohCK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      "]]}}, {{}, {}, 
    {RGBColor[1, 0.5, 0], Thickness[Large], Dashing[{0.03, 0.03}], 
     LineBox[CompressedData["
1:eJwt1nc0Fo73B3AKSZLs8dhSRkIIGdfem8eDMkq2ZO+QUEhIqEhWRsoIhTxX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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 100}, {-2.5, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.543710751317911*^9, 3.543711123277444*^9, 
  3.54371132227647*^9, 3.543784215519438*^9, 3.543786227764391*^9, 
  3.543787328878551*^9, 3.543787412274705*^9, 3.543787575256463*^9, 
  3.543787735386765*^9, 3.543787773700317*^9, 3.543790580520088*^9, 
  3.543790612406308*^9, 3.5438313026105413`*^9, 3.543838151710791*^9, 
  3.543838350353858*^9, 3.543838829443139*^9, 3.543838904529771*^9, 
  3.5438433521368217`*^9, 3.543918698538065*^9, 3.5439440348387814`*^9, 
  3.543960697867902*^9, 3.544014798381616*^9, 3.5443647880701313`*^9, 
  3.544710290328843*^9, 3.544713493409953*^9, 3.544727693571191*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Blue", ":", "iCa"}], ",", " ", 
   RowBox[{"Green", ":", "iT"}], ",", " ", 
   RowBox[{"Red", ":", "iN"}], ",", " ", 
   RowBox[{"Orange", ":", "iP"}]}], " ", "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710767097969*^9, 3.543710814255006*^9}, 
   3.543711322276619*^9}],

Cell["(* Graphing Fig. 2C: Potassium Currents *)", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710822384091*^9, 3.5437108734162292`*^9}, 
   3.54371132227675*^9},
 FontSize->14,
 Background->RGBColor[1, 0.9, 1]],

Cell[BoxData[
 RowBox[{"graphK", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"iK", "[", 
       RowBox[{
        RowBox[{"v", "[", "t", "]"}], ",", 
        RowBox[{"n", "[", "t", "]"}]}], "]"}], "/.", "solutionVoltageNew"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", " ", "Thick"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "25"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (ms)\>\"", ",", " ", "\"\<Current (nA)\>\""}], 
      "}"}]}]}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{"iK", " ", "from", " ", "the", " ", "ionic", " ", "function"}], 
   " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710946470175*^9, 3.543710950132893*^9}, {
   3.543711131830517*^9, 3.54371113419119*^9}, 3.543711322276885*^9, {
   3.5448033071925087`*^9, 3.544803316880871*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwtlnc81m/Ux22KJHtvsvfKOse4b3uUdVuZ2Zll3CFJdghJJdokKbJJUVFC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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 15}, {-1, 25}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.5437109510555153`*^9, 3.54371113647721*^9, 
  3.5437113222770243`*^9, 3.5437842156291523`*^9, 3.5437862278391447`*^9, 
  3.543787328996612*^9, 3.5437874123705797`*^9, 3.543787575366776*^9, 
  3.543787735490946*^9, 3.543787773823906*^9, 3.543790580605475*^9, 
  3.543790612545525*^9, 3.543831302686399*^9, 3.543838151821927*^9, 
  3.543838350442403*^9, 3.54383882959575*^9, 3.5438389046096773`*^9, 
  3.543843352241238*^9, 3.543918698759828*^9, 3.543944034917753*^9, 
  3.543960697993482*^9, 3.544014798466034*^9, 3.544364788155931*^9, 
  3.544710290415996*^9, 3.544713493570657*^9, 3.544727693727838*^9}],

Cell[BoxData[
 RowBox[{"graphA", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"iA", "[", 
       RowBox[{
        RowBox[{"v", "[", "t", "]"}], ",", 
        RowBox[{"mA", "[", "t", "]"}], ",", 
        RowBox[{"hA", "[", "t", "]"}]}], "]"}], "/.", "solutionVoltageNew"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "25"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", "Thick", ",", 
       RowBox[{"Dashing", "[", 
        RowBox[{"{", 
         RowBox[{"0.005", ",", "0.005"}], "}"}], "]"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time(ms)\>\"", ",", " ", "\"\<Current (nA)\>\""}], 
      "}"}]}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{"iA", " ", "from", " ", "the", " ", "ionic", " ", "function"}], 
   "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543710975868339*^9, 3.543710979869089*^9}, {
   3.5437110367475653`*^9, 3.543711037762876*^9}, 3.543711322277163*^9, {
   3.544803320585539*^9, 3.54480332647302*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Dashing[{0.005, 0.005}], 
    LineBox[CompressedData["
1:eJwt13k81N/3OHBJUiFk37fIvu/LOSipEMYylqJUCIWILCWVIpV2jH2nFGUp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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time(ms)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 15}, {-1, 25}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.543710980711339*^9, 3.543711139383005*^9, 
  3.5437113222773123`*^9, 3.54378421568218*^9, 3.543786227892041*^9, 
  3.543787329070451*^9, 3.5437874124442663`*^9, 3.543787575428986*^9, 
  3.5437877355447083`*^9, 3.543787773885853*^9, 3.543790580679758*^9, 
  3.543790612604703*^9, 3.543831302738975*^9, 3.543838151870253*^9, 
  3.543838350501281*^9, 3.5438388297298203`*^9, 3.54383890466148*^9, 
  3.543843352336467*^9, 3.543918698897839*^9, 3.543944034971601*^9, 
  3.5439606980844173`*^9, 3.54401479852547*^9, 3.544364788213097*^9, 
  3.544710290473175*^9, 3.544713493685293*^9, 3.544727693873454*^9}],

Cell[BoxData[
 RowBox[{"graphLeak", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"ileak", "[", 
       RowBox[{"v", "[", "t", "]"}], "]"}], "/.", "solutionVoltageNew"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "25"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Green", ",", "Thick", ",", 
       RowBox[{"Dashing", "[", 
        RowBox[{"{", 
         RowBox[{"0.03", ",", "0.03"}], "}"}], "]"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (ms)\>\"", ",", " ", "\"\<Current (nA)\>\""}], 
      "}"}]}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"iLeak", " ", "from", " ", "the", " ", "ionic", " ", "function"}], 
   "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543711002364229*^9, 3.5437110056837254`*^9}, {
   3.543711143399537*^9, 3.543711145999103*^9}, 3.543711322277451*^9, {
   3.544803330240375*^9, 3.544803338648222*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0, 1, 0], Thickness[Large], Dashing[{0.03, 0.03}], 
    LineBox[CompressedData["
1:eJwt13c81d//AHBEQypZWWUmK9nbfb+MChll5FpJyYhkJSKpkJWSspJRCiUj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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 15}, {-1, 25}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.543711006628312*^9, 3.543711146905767*^9, 
  3.5437113222776003`*^9, 3.543784215732016*^9, 3.5437862279462423`*^9, 
  3.543787329135147*^9, 3.543787412507077*^9, 3.5437875755071707`*^9, 
  3.543787735590925*^9, 3.5437877739563704`*^9, 3.543790580750896*^9, 
  3.543790612654697*^9, 3.543831302787938*^9, 3.5438381519741583`*^9, 
  3.5438383505672197`*^9, 3.5438388299605713`*^9, 3.543838904731642*^9, 
  3.543843352513171*^9, 3.543918698952736*^9, 3.543944035117819*^9, 
  3.543960698169146*^9, 3.54401479858532*^9, 3.54436478827711*^9, 
  3.544710290534586*^9, 3.544713493784943*^9, 3.544727694189457*^9}],

Cell[BoxData[
 RowBox[{"figure2C", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"graphK", ",", "graphA", ",", "graphLeak"}], "]"}], 
  RowBox[{"(*", "Composite", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{
  3.543711018130746*^9, 3.543711322277741*^9, {3.5448033414127407`*^9, 
   3.544803344116884*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwtlnc81m/Ux22KJHtvsvfKOse4b3uUdVuZ2Zll3CFJdghJJdokKbJJUVFC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      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], Dashing[{0.005, 0.005}], 
     LineBox[CompressedData["
1:eJwt13k81N/3OHBJUiFk37fIvu/LOSipEMYylqJUCIWILCWVIpV2jH2nFGUp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      "]]}}, {{}, {}, 
    {RGBColor[0, 1, 0], Thickness[Large], Dashing[{0.03, 0.03}], 
     LineBox[CompressedData["
1:eJwt13c81d//AHBEQypZWWUmK9nbfb+MChll5FpJyYhkJSKpkJWSspJRCiUj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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 15}, {-1, 25}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.5437110192648897`*^9, 3.5437111495785103`*^9, 
  3.5437113222778893`*^9, 3.5437842158844967`*^9, 3.543786228075632*^9, 
  3.543787329204192*^9, 3.543787412594878*^9, 3.543787575560354*^9, 
  3.543787735658512*^9, 3.5437877740165997`*^9, 3.54379058080916*^9, 
  3.5437906127344723`*^9, 3.5438313028427687`*^9, 3.543838152075103*^9, 
  3.543838350632333*^9, 3.5438388300121927`*^9, 3.54383890480061*^9, 
  3.5438433525753508`*^9, 3.543918699013309*^9, 3.543944035193314*^9, 
  3.543960698245735*^9, 3.5440147986430073`*^9, 3.544364788349227*^9, 
  3.544710290597808*^9, 3.544713493887693*^9, 3.544727694313861*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Red", ":", "iA"}], ",", " ", 
   RowBox[{"Blue", ":", "iK"}], ",", " ", 
   RowBox[{"Green", ":", "ileak"}]}], " ", "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543711022569325*^9, 3.54371102814326*^9}, {
   3.543711162674859*^9, 3.543711180466694*^9}, 3.543711322278028*^9}],

Cell["(* Graphing 2D: SK current *)", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543711224682575*^9, 3.543711243129774*^9}, 
   3.5437113222781553`*^9},
 FontSize->14,
 Background->RGBColor[1, 0.9, 1]],

Cell[BoxData[
 RowBox[{"graphSK", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"iSK", "[", 
       RowBox[{
        RowBox[{"v", "[", "t", "]"}], ",", 
        RowBox[{"zSK", "[", "t", "]"}]}], "]"}], "/.", "solutionVoltageNew"}],
      "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "100"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (ms)\>\"", ",", " ", "\"\<Current (nA)\>\""}], 
      "}"}]}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{"iSK", " ", "from", " ", "the", " ", "ionic", " ", "function"}], 
   " ", "*)"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.543711265275556*^9, 3.543711269138948*^9}, 
   3.543711322278288*^9, {3.544803352927909*^9, 3.54480336042352*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwt13k0ld/7N3CzRCWReZ6HzGTqXNenMg/hHMcxpTKTzKJMIQohUaZQShFC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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time (ms)\"", TraditionalForm], 
    FormBox["\"Current (nA)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 100}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{3.5437112702955103`*^9, 3.543711322278425*^9, 
  3.543784215955554*^9, 3.543786228197111*^9, 3.543787329277965*^9, 
  3.5437874127078047`*^9, 3.543787575636573*^9, 3.543787735788157*^9, 
  3.543787774125945*^9, 3.543790580886454*^9, 3.5437906128229218`*^9, 
  3.543831302914832*^9, 3.543838152263878*^9, 3.543838350757429*^9, 
  3.5438388301175547`*^9, 3.5438389048873*^9, 3.54384335272886*^9, 
  3.543918699096305*^9, 3.543944035299811*^9, 3.543960698340851*^9, 
  3.544014798729862*^9, 3.544364788436921*^9, 3.544710290680542*^9, 
  3.544713494086598*^9, 3.5447276944580803`*^9}]
}, Closed]]
},
WindowSize->{1284, 756},
WindowMargins->{{-1, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 5, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 276, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[858, 30, 391, 8, 46, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1252, 40, 438, 8, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1693, 50, 2580, 50, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[4276, 102, 7529, 226, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[11808, 330, 5838, 151, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[17649, 483, 2926, 86, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[20578, 571, 405, 8, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[20986, 581, 585, 15, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[21574, 598, 39793, 659, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[61404, 1262, 328, 9, 43, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[61735, 1273, 4627, 85, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[66365, 1360, 17082, 525, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[83450, 1887, 16435, 401, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[99888, 2290, 6541, 207, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[106432, 2499, 962, 28, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[107397, 2529, 10077, 170, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[117477, 2701, 277, 6, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Closed]],
Cell[CellGroupData[{
Cell[117791, 2712, 318, 7, 43, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[118112, 2721, 289, 6, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[118404, 2729, 325, 6, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[118732, 2737, 16087, 397, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[134822, 3136, 6659, 208, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[141484, 3346, 309, 7, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[141796, 3355, 1363, 32, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[143162, 3389, 9709, 164, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[152874, 3555, 642, 12, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[153519, 3569, 926, 24, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[154448, 3595, 4836, 84, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[159287, 3681, 919, 24, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[160209, 3707, 4048, 71, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[164260, 3780, 1089, 28, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[165352, 3810, 4865, 85, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[170220, 3897, 1091, 28, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[171314, 3927, 3991, 70, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[175308, 3999, 1096, 28, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[176407, 4029, 4698, 82, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[181108, 4113, 1076, 28, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[182187, 4143, 4937, 86, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[187127, 4231, 1023, 28, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[188153, 4261, 4599, 80, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[192755, 4343, 920, 26, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[193678, 4371, 4460, 78, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[198141, 4451, 922, 26, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[199066, 4479, 5107, 89, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[204176, 4570, 924, 26, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[205103, 4598, 2688, 49, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[207794, 4649, 921, 26, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[208718, 4677, 4494, 79, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[213215, 4758, 926, 26, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[214144, 4786, 5469, 95, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[219616, 4883, 922, 26, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[220541, 4911, 4645, 81, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[225189, 4994, 921, 26, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[226113, 5022, 5077, 88, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[231193, 5112, 922, 26, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[232118, 5140, 6072, 105, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[238193, 5247, 279, 5, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}]
}, Closed]],
Cell[CellGroupData[{
Cell[238509, 5257, 262, 5, 43, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[238774, 5264, 1424, 35, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[240201, 5301, 1322, 23, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[241526, 5326, 682, 14, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[242211, 5342, 957, 16, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[243171, 5360, 439, 9, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[243613, 5371, 804, 17, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[244420, 5390, 1813, 32, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}]
}, Closed]],
Cell[CellGroupData[{
Cell[246270, 5427, 349, 8, 43, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[246622, 5437, 394, 8, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[247019, 5447, 22059, 652, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[269081, 6101, 16250, 399, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[285334, 6502, 6430, 204, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[291767, 6708, 1499, 35, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[293269, 6745, 9512, 162, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[302784, 6909, 400, 9, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}]
}, Closed]],
Cell[CellGroupData[{
Cell[303221, 6923, 251, 5, 43, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[303475, 6930, 430, 7, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[303908, 6939, 242, 5, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[304153, 6946, 1340, 36, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[305496, 6984, 28285, 468, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[333784, 7454, 1405, 38, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[335192, 7494, 12318, 207, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[347513, 7703, 428, 9, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[347944, 7714, 39525, 654, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[387472, 8370, 287, 7, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[387762, 8379, 245, 5, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[388010, 8386, 1833, 49, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[389846, 8437, 13856, 231, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[403705, 8670, 1442, 40, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[405150, 8712, 15664, 261, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[420817, 8975, 1447, 39, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[422267, 9016, 11874, 200, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[434144, 9218, 1397, 38, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[435544, 9258, 10496, 177, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[446043, 9437, 373, 9, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[446419, 9448, 48821, 809, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[495243, 10259, 379, 9, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[495625, 10270, 253, 5, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[495881, 10277, 1205, 32, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[497089, 10311, 12614, 211, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[509706, 10524, 1406, 38, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[511115, 10564, 14216, 238, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[525334, 10804, 1313, 35, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[526650, 10841, 10238, 172, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[536891, 11015, 349, 8, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[537243, 11025, 35022, 581, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[572268, 11608, 381, 8, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[572652, 11618, 241, 5, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[572896, 11625, 1123, 30, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}],
Cell[574022, 11657, 12010, 201, 70, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}]
}, Closed]]
}
]
*)

(* End of internal cache information *)

